/********************************************************************************
** Form generated from reading UI file 'x265ConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_X265CONFIGDIALOG_H
#define UI_X265CONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_x265ConfigDialog
{
public:
    QVBoxLayout *_11;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacer_8;
    QLabel *label_3;
    QComboBox *configurationComboBox;
    QPushButton *saveAsButton;
    QPushButton *deleteButton;
    QSpacerItem *spacer_9;
    QSpacerItem *spacer_7;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBoxBasic;
    QVBoxLayout *verticalLayoutBasic;
    QCheckBox *useAdvancedConfigurationCheckBox;
    QGridLayout *gridLayoutBasic;
    QLabel *label_46;
    QHBoxLayout *horizontalLayoutProfile;
    QComboBox *profileComboBox;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayoutTuning;
    QComboBox *tuningComboBox;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayoutIdc;
    QComboBox *idcLevelComboBox;
    QSpacerItem *horizontalSpacer_11;
    QLabel *label_45;
    QLabel *labelPoolThread;
    QLabel *label_41;
    QHBoxLayout *horizontalLayoutPreset;
    QComboBox *presetComboBox;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayoutThreads;
    QComboBox *comboBoxPoolThreads;
    QSpacerItem *horizontalSpacer_5;
    QLabel *labelFrameThreads;
    QComboBox *comboBoxFrameThreads;
    QSpacerItem *horizontalSpacer_12;
    QLabel *label_53;
    QLabel *labelBitDepth;
    QHBoxLayout *horizontalLayoutBitDepth;
    QComboBox *comboBoxBitDepth;
    QSpacerItem *horizontalSpacerBitDepth;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_6;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout;
    QLabel *targetRateControlLabel1;
    QHBoxLayout *hboxLayout1;
    QComboBox *encodingModeComboBox;
    QSpacerItem *horizontalSpacer_14;
    QLabel *label;
    QHBoxLayout *hboxLayout2;
    QSpinBox *targetRateControlSpinBox;
    QLabel *targetRateControlLabel2;
    QSpacerItem *spacer_5;
    QVBoxLayout *verticalLayout_14;
    QHBoxLayout *hboxLayout3;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout4;
    QLabel *quantiserLabel1;
    QSpacerItem *spacerItem1;
    QLabel *quantiserLabel2;
    QSpacerItem *spacerItem2;
    QLabel *quantiserLabel3;
    QSlider *quantiserSlider;
    QSpinBox *quantiserSpinBox;
    QSpacerItem *spacer_4;
    QCheckBox *strictCbrCheckBox;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabAdvancedRC;
    QVBoxLayout *verticalLayout_12;
    QGroupBox *groupBox_20;
    QVBoxLayout *verticalLayout_13;
    QCheckBox *maxCrfCheckBox;
    QHBoxLayout *_16;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *_17;
    QVBoxLayout *_18;
    QHBoxLayout *_19;
    QLabel *quantiserLabel1_2;
    QSpacerItem *spacerItem3;
    QLabel *quantiserLabel2_2;
    QSpacerItem *spacerItem4;
    QLabel *quantiserLabel3_2;
    QSlider *maxCrfSlider;
    QSpinBox *maxCrfSpinBox;
    QSpacerItem *spacer_22;
    QCheckBox *cuTreeCheckBox;
    QHBoxLayout *_36;
    QLabel *lblLookahead;
    QSpinBox *lookaheadSpinBox;
    QLabel *lblLookaheadFrames;
    QSpacerItem *spacer_3;
    QGridLayout *_20;
    QLabel *label_55;
    QHBoxLayout *_22;
    QComboBox *spsiComboBox;
    QSpacerItem *spacer_63;
    QSpacerItem *verticalSpacer_4;
    QWidget *tabMotion;
    QVBoxLayout *vboxLayout1;
    QGroupBox *groupBox_11;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout5;
    QLabel *label_38;
    QHBoxLayout *hboxLayout6;
    QComboBox *meMethodComboBox;
    QSpacerItem *spacer_10;
    QHBoxLayout *hboxLayout7;
    QHBoxLayout *hboxLayout8;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout9;
    QLabel *label_35;
    QSpacerItem *spacer_11;
    QLabel *label_36;
    QSpacerItem *spacer_13;
    QLabel *label_37;
    QSlider *meSlider;
    QSpinBox *meSpinBox;
    QSpacerItem *spacer_12;
    QGroupBox *groupBox_19;
    QVBoxLayout *vboxLayout4;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout10;
    QSpinBox *mvRangeSpinBox;
    QSpacerItem *spacer_15;
    QLabel *label_39;
    QGroupBox *groupBox_18;
    QGridLayout *gridLayout2;
    QGridLayout *gridLayout3;
    QLabel *lblBPredict;
    QCheckBox *weightedPredictCheckBox;
    QCheckBox *bIntraCheckBox;
    QCheckBox *constrainedIntraCheckBox;
    QHBoxLayout *hboxLayout11;
    QLabel *lblMParts;
    QCheckBox *rectInterCheckBox;
    QCheckBox *AMPInterCheckBox;
    QCheckBox *limitInterModesCheckBox;
    QGridLayout *gridLayout4;
    QLabel *lblWeightedPPredict;
    QHBoxLayout *hboxLayout12;
    QComboBox *weightedPPredictComboBox;
    QSpacerItem *spacer_18;
    QSpacerItem *spacer_19;
    QWidget *tabFrame;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *loopFilterCheckBox;
    QCheckBox *openGopCheckBox;
    QGridLayout *gridLayout_2;
    QCheckBox *interlacedCheckBox;
    QHBoxLayout *horizontalLayout;
    QComboBox *interlacedComboBox;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *_3;
    QLabel *maxRefFramesLabel;
    QHBoxLayout *hboxLayout13;
    QSpinBox *refFramesSpinBox;
    QSpacerItem *spacer_24;
    QLabel *refLimitLabel;
    QCheckBox *limitRefCUCheckBox;
    QCheckBox *limitRefDepthCheckBox;
    QGroupBox *groupBoxBframes;
    QGridLayout *gridLayout5;
    QLabel *label_31;
    QHBoxLayout *hboxLayout14;
    QSpinBox *maxBFramesSpinBox;
    QSpacerItem *spacer_25;
    QLabel *label_29;
    QHBoxLayout *hboxLayout15;
    QSpinBox *BFrameBiasSpinBox;
    QSpacerItem *spacer_26;
    QLabel *label_4;
    QHBoxLayout *hboxLayout16;
    QComboBox *adaptiveBFrameComboBox;
    QSpacerItem *spacer_27;
    QLabel *label_33;
    QHBoxLayout *hboxLayout17;
    QComboBox *bFrameRefComboBox;
    QSpacerItem *spacer_28;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout_3;
    QLabel *label_34;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_28;
    QSpinBox *minGopSizeSpinBox;
    QSpacerItem *spacer_29;
    QLabel *label_26;
    QSpinBox *maxGopSizeSpinBox;
    QSpacerItem *spacer_30;
    QLabel *label_27;
    QHBoxLayout *hboxLayout18;
    QSpinBox *IFrameThresholdSpinBox;
    QSpacerItem *spacer_31;
    QSpacerItem *spacer_32;
    QWidget *tabAnalysis;
    QVBoxLayout *vboxLayout5;
    QGroupBox *groupBox_12;
    QVBoxLayout *verticalLayout_10;
    QCheckBox *fastPSkipCheckBox;
    QCheckBox *dctDecimateCheckBox;
    QGridLayout *gridLayout6;
    QLabel *lblRDO;
    QHBoxLayout *hboxLayout19;
    QSpacerItem *spacerItem5;
    QLabel *lblPsychoRDO;
    QSpinBox *rdoSpinBox;
    QSpacerItem *spacerItem6;
    QHBoxLayout *hboxLayout20;
    QLabel *lblRDOPsyVS;
    QDoubleSpinBox *psychoRdoSpinBox;
    QSpacerItem *spacerItem7;
    QLabel *lblRDOQ;
    QHBoxLayout *hboxLayout21;
    QSpacerItem *spacerItem8;
    QLabel *lblRDOQLevel;
    QSpinBox *rdoqSpinBox;
    QSpacerItem *spacerItem9;
    QHBoxLayout *hboxLayout22;
    QLabel *lblPsyRDOQ;
    QDoubleSpinBox *psychoRdoqSpinBox;
    QSpacerItem *spacerItem10;
    QGridLayout *gridLayout_8;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_15;
    QSpinBox *noiseReductionIntraSpinBox;
    QLabel *label_16;
    QSpinBox *noiseReductionInterSpinBox;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *strongIntraSmoothingCheckBox;
    QGroupBox *groupBoxQuantMatrix;
    QVBoxLayout *vboxLayout6;
    QVBoxLayout *vboxLayout7;
    QRadioButton *matrixFlatRadioButton;
    QRadioButton *matrixJvtRadioButton;
    QHBoxLayout *hboxLayout23;
    QRadioButton *matrixCustomRadioButton;
    QPushButton *matrixCustomEditButton;
    QSpacerItem *spacer_38;
    QSpacerItem *spacer_39;
    QWidget *tabQuantiser;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *groupBox_4;
    QVBoxLayout *vboxLayout8;
    QGridLayout *gridLayout7;
    QLabel *label_20;
    QHBoxLayout *hboxLayout24;
    QSpinBox *quantiserMaxStepSpinBox;
    QSpacerItem *spacer_42;
    QLabel *label_6;
    QHBoxLayout *hboxLayout25;
    QDoubleSpinBox *quantiserPbRatioSpinBox;
    QSpacerItem *spacer_44;
    QLabel *label_17;
    QHBoxLayout *hboxLayout26;
    QSpinBox *cbChromaLumaOffsetSpinBox;
    QLabel *label_40;
    QSpacerItem *horizontalSpacer_13;
    QSpinBox *crChromaLumaOffsetSpinBox;
    QLabel *label_54;
    QSpacerItem *spacer_41;
    QLabel *label_7;
    QHBoxLayout *hboxLayout27;
    QDoubleSpinBox *quantiserIpRatioSpinBox;
    QSpacerItem *spacer_43;
    QGroupBox *groupBoxQuantCurveCompress;
    QVBoxLayout *vboxLayout9;
    QHBoxLayout *hboxLayout28;
    QLabel *label_8;
    QHBoxLayout *hboxLayout29;
    QSpinBox *quantiserCurveCompressSpinBox;
    QLabel *label_18;
    QSpacerItem *spacer_49;
    QGridLayout *gridLayout8;
    QLabel *label_21;
    QHBoxLayout *hboxLayout30;
    QDoubleSpinBox *quantiserBeforeCompressSpinBox;
    QSpacerItem *spacer_50;
    QHBoxLayout *hboxLayout31;
    QDoubleSpinBox *quantiserAfterCompressSpinBox;
    QSpacerItem *spacer_48;
    QLabel *label_22;
    QGroupBox *aqGroupBox;
    QVBoxLayout *verticalLayout_8;
    QGridLayout *gridLayout_4;
    QCheckBox *aqVarianceCheckBox;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *aqAlgoComboBox;
    QSpacerItem *spacer_47;
    QLabel *aqStrengthLabel;
    QHBoxLayout *horizontalLayout_7;
    QDoubleSpinBox *aqStrengthSpinBox;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *spacer_52;
    QWidget *tabDispaly;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *groupColor;
    QGridLayout *gridLayout9;
    QLabel *label_50;
    QHBoxLayout *_8;
    QComboBox *videoFormatComboBox;
    QSpacerItem *spacer_68;
    QLabel *label_19;
    QHBoxLayout *_9;
    QComboBox *colourPrimariesComboBox;
    QSpacerItem *spacer_69;
    QLabel *label_48;
    QHBoxLayout *_5;
    QComboBox *transferCharacteristicsComboBox;
    QSpacerItem *spacer_67;
    QLabel *label_47;
    QHBoxLayout *_7;
    QComboBox *colourMatrixComboBox;
    QSpacerItem *spacer_71;
    QGroupBox *groupBoxPAR;
    QVBoxLayout *vboxLayout10;
    QLabel *labelPAR;
    QGridLayout *gridLayout10;
    QRadioButton *sarUnspecifiedRadioButton;
    QRadioButton *sarPredefinedRadioButton;
    QHBoxLayout *hboxLayout32;
    QComboBox *sarPredefinedComboBox;
    QSpacerItem *spacer_62;
    QRadioButton *sarCustomRadioButton;
    QHBoxLayout *hboxLayout33;
    QSpinBox *sarCustomSpinBox1;
    QLabel *sarCustomLabel;
    QSpinBox *sarCustomSpinBox2;
    QSpacerItem *spacer_64;
    QRadioButton *sarAsInputRadioButton;
    QSpacerItem *spacerItem11;
    QWidget *tabAdvanced1;
    QVBoxLayout *vboxLayout11;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout12;
    QGridLayout *gridLayout11;
    QLabel *label_9;
    QLabel *label_14;
    QHBoxLayout *hboxLayout34;
    QSpinBox *vbvBufferSizeSpinBox;
    QLabel *label_12;
    QSpacerItem *spacer_55;
    QHBoxLayout *hboxLayout35;
    QSpinBox *vbvBufferOccupancySpinBox;
    QLabel *label_13;
    QSpacerItem *spacer_58;
    QHBoxLayout *hboxLayout36;
    QSpinBox *vbvMaxBitrateSpinBox;
    QLabel *label_10;
    QSpacerItem *spacer_56;
    QLabel *label_11;
    QGroupBox *slicingGroupBox;
    QGridLayout *gridLayout12;
    QLabel *label_25;
    QLabel *label_23;
    QHBoxLayout *hboxLayout37;
    QSpinBox *maxSliceSizeSpinBox;
    QLabel *label_32;
    QSpacerItem *spacer_54;
    QLabel *label_24;
    QHBoxLayout *hboxLayout38;
    QSpinBox *maxSliceMbSpinBox;
    QSpacerItem *spacer_57;
    QHBoxLayout *hboxLayout39;
    QSpinBox *slicesPerFrameSpinBox;
    QSpacerItem *spacer_53;
    QGroupBox *groupBox_21;
    QVBoxLayout *vboxLayout13;
    QHBoxLayout *_12;
    QTableView *zoneTableView;
    QVBoxLayout *_13;
    QPushButton *zoneAddButton;
    QPushButton *zoneEditButton;
    QPushButton *zoneDeleteButton;
    QSpacerItem *spacer_59;
    QWidget *tabAdvanced2;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_17;
    QVBoxLayout *_2;
    QVBoxLayout *_4;
    QRadioButton *threadDisableRadioButton;
    QRadioButton *threadAutoDetectRadioButton;
    QHBoxLayout *_14;
    QRadioButton *threadCustomRadioButton;
    QSpinBox *threadCustomSpinBox;
    QSpacerItem *spacer_2;
    QCheckBox *repeatabilityCheckBox;
    QCheckBox *sliceThreadingCheckBox;
    QHBoxLayout *_15;
    QCheckBox *threadedLookaheadCheckBox;
    QSpinBox *threadedLookaheadSpinBox;
    QLabel *lblThreadedFrames;
    QSpacerItem *spacer;
    QSpacerItem *verticalSpacer;
    QWidget *tabOutput;
    QVBoxLayout *vboxLayout14;
    QGroupBox *groupBox_16;
    QVBoxLayout *vboxLayout15;
    QCheckBox *accessUnitCheckBox;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_52;
    QSpacerItem *spacerItem12;
    QGridLayout *gridLayout13;
    QLabel *label_51;
    QHBoxLayout *_6;
    QComboBox *overscanComboBox;
    QSpacerItem *spacer_70;
    QLabel *hrdLabel;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *hrdComboBox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_49;
    QHBoxLayout *_10;
    QSpinBox *chromaSampleSpinBox;
    QSpacerItem *spacer_66;
    QCheckBox *fullRangeSamplesCheckBox;
    QSpacerItem *spacer_60;
    QHBoxLayout *hboxLayout40;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *x265ConfigDialog)
    {
        if (x265ConfigDialog->objectName().isEmpty())
            x265ConfigDialog->setObjectName(QString::fromUtf8("x265ConfigDialog"));
        x265ConfigDialog->resize(567, 772);
        _11 = new QVBoxLayout(x265ConfigDialog);
        _11->setObjectName(QString::fromUtf8("_11"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        spacer_8 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacer_8);

        label_3 = new QLabel(x265ConfigDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        hboxLayout->addWidget(label_3);

        configurationComboBox = new QComboBox(x265ConfigDialog);
        configurationComboBox->setObjectName(QString::fromUtf8("configurationComboBox"));
        configurationComboBox->setMinimumSize(QSize(200, 0));

        hboxLayout->addWidget(configurationComboBox);

        saveAsButton = new QPushButton(x265ConfigDialog);
        saveAsButton->setObjectName(QString::fromUtf8("saveAsButton"));

        hboxLayout->addWidget(saveAsButton);

        deleteButton = new QPushButton(x265ConfigDialog);
        deleteButton->setObjectName(QString::fromUtf8("deleteButton"));

        hboxLayout->addWidget(deleteButton);

        spacer_9 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacer_9);


        _11->addLayout(hboxLayout);

        spacer_7 = new QSpacerItem(0, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        _11->addItem(spacer_7);

        tabWidget = new QTabWidget(x265ConfigDialog);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabGeneral = new QWidget();
        tabGeneral->setObjectName(QString::fromUtf8("tabGeneral"));
        verticalLayout_5 = new QVBoxLayout(tabGeneral);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        groupBoxBasic = new QGroupBox(tabGeneral);
        groupBoxBasic->setObjectName(QString::fromUtf8("groupBoxBasic"));
        verticalLayoutBasic = new QVBoxLayout(groupBoxBasic);
        verticalLayoutBasic->setObjectName(QString::fromUtf8("verticalLayoutBasic"));
        useAdvancedConfigurationCheckBox = new QCheckBox(groupBoxBasic);
        useAdvancedConfigurationCheckBox->setObjectName(QString::fromUtf8("useAdvancedConfigurationCheckBox"));

        verticalLayoutBasic->addWidget(useAdvancedConfigurationCheckBox);

        gridLayoutBasic = new QGridLayout();
        gridLayoutBasic->setObjectName(QString::fromUtf8("gridLayoutBasic"));
        label_46 = new QLabel(groupBoxBasic);
        label_46->setObjectName(QString::fromUtf8("label_46"));

        gridLayoutBasic->addWidget(label_46, 2, 0, 1, 1);

        horizontalLayoutProfile = new QHBoxLayout();
        horizontalLayoutProfile->setObjectName(QString::fromUtf8("horizontalLayoutProfile"));
        profileComboBox = new QComboBox(groupBoxBasic);
        profileComboBox->setObjectName(QString::fromUtf8("profileComboBox"));

        horizontalLayoutProfile->addWidget(profileComboBox);

        horizontalSpacer_10 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutProfile->addItem(horizontalSpacer_10);


        gridLayoutBasic->addLayout(horizontalLayoutProfile, 2, 1, 1, 1);

        horizontalLayoutTuning = new QHBoxLayout();
        horizontalLayoutTuning->setObjectName(QString::fromUtf8("horizontalLayoutTuning"));
        tuningComboBox = new QComboBox(groupBoxBasic);
        tuningComboBox->setObjectName(QString::fromUtf8("tuningComboBox"));

        horizontalLayoutTuning->addWidget(tuningComboBox);

        horizontalSpacer_9 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutTuning->addItem(horizontalSpacer_9);


        gridLayoutBasic->addLayout(horizontalLayoutTuning, 1, 1, 1, 1);

        horizontalLayoutIdc = new QHBoxLayout();
        horizontalLayoutIdc->setObjectName(QString::fromUtf8("horizontalLayoutIdc"));
        idcLevelComboBox = new QComboBox(groupBoxBasic);
        idcLevelComboBox->setObjectName(QString::fromUtf8("idcLevelComboBox"));

        horizontalLayoutIdc->addWidget(idcLevelComboBox);

        horizontalSpacer_11 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutIdc->addItem(horizontalSpacer_11);


        gridLayoutBasic->addLayout(horizontalLayoutIdc, 3, 1, 1, 1);

        label_45 = new QLabel(groupBoxBasic);
        label_45->setObjectName(QString::fromUtf8("label_45"));

        gridLayoutBasic->addWidget(label_45, 1, 0, 1, 1);

        labelPoolThread = new QLabel(groupBoxBasic);
        labelPoolThread->setObjectName(QString::fromUtf8("labelPoolThread"));

        gridLayoutBasic->addWidget(labelPoolThread, 4, 0, 1, 1);

        label_41 = new QLabel(groupBoxBasic);
        label_41->setObjectName(QString::fromUtf8("label_41"));

        gridLayoutBasic->addWidget(label_41, 0, 0, 1, 1);

        horizontalLayoutPreset = new QHBoxLayout();
        horizontalLayoutPreset->setObjectName(QString::fromUtf8("horizontalLayoutPreset"));
        presetComboBox = new QComboBox(groupBoxBasic);
        presetComboBox->setObjectName(QString::fromUtf8("presetComboBox"));

        horizontalLayoutPreset->addWidget(presetComboBox);

        horizontalSpacer_8 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutPreset->addItem(horizontalSpacer_8);


        gridLayoutBasic->addLayout(horizontalLayoutPreset, 0, 1, 1, 1);

        horizontalLayoutThreads = new QHBoxLayout();
        horizontalLayoutThreads->setObjectName(QString::fromUtf8("horizontalLayoutThreads"));
        comboBoxPoolThreads = new QComboBox(groupBoxBasic);
        comboBoxPoolThreads->setObjectName(QString::fromUtf8("comboBoxPoolThreads"));

        horizontalLayoutThreads->addWidget(comboBoxPoolThreads);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        horizontalLayoutThreads->addItem(horizontalSpacer_5);

        labelFrameThreads = new QLabel(groupBoxBasic);
        labelFrameThreads->setObjectName(QString::fromUtf8("labelFrameThreads"));

        horizontalLayoutThreads->addWidget(labelFrameThreads);

        comboBoxFrameThreads = new QComboBox(groupBoxBasic);
        comboBoxFrameThreads->setObjectName(QString::fromUtf8("comboBoxFrameThreads"));

        horizontalLayoutThreads->addWidget(comboBoxFrameThreads);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutThreads->addItem(horizontalSpacer_12);


        gridLayoutBasic->addLayout(horizontalLayoutThreads, 4, 1, 1, 1);

        label_53 = new QLabel(groupBoxBasic);
        label_53->setObjectName(QString::fromUtf8("label_53"));

        gridLayoutBasic->addWidget(label_53, 3, 0, 1, 1);

        labelBitDepth = new QLabel(groupBoxBasic);
        labelBitDepth->setObjectName(QString::fromUtf8("labelBitDepth"));

        gridLayoutBasic->addWidget(labelBitDepth, 5, 0, 1, 1);

        horizontalLayoutBitDepth = new QHBoxLayout();
        horizontalLayoutBitDepth->setObjectName(QString::fromUtf8("horizontalLayoutBitDepth"));
        comboBoxBitDepth = new QComboBox(groupBoxBasic);
        comboBoxBitDepth->setObjectName(QString::fromUtf8("comboBoxBitDepth"));

        horizontalLayoutBitDepth->addWidget(comboBoxBitDepth);

        horizontalSpacerBitDepth = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutBitDepth->addItem(horizontalSpacerBitDepth);


        gridLayoutBasic->addLayout(horizontalLayoutBitDepth, 5, 1, 1, 1);


        verticalLayoutBasic->addLayout(gridLayoutBasic);


        verticalLayout_5->addWidget(groupBoxBasic);

        groupBox_2 = new QGroupBox(tabGeneral);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        gridLayout_6 = new QGridLayout(groupBox_2);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_6->addItem(spacerItem, 5, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        targetRateControlLabel1 = new QLabel(groupBox_2);
        targetRateControlLabel1->setObjectName(QString::fromUtf8("targetRateControlLabel1"));

        gridLayout->addWidget(targetRateControlLabel1, 1, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        encodingModeComboBox = new QComboBox(groupBox_2);
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->setObjectName(QString::fromUtf8("encodingModeComboBox"));

        hboxLayout1->addWidget(encodingModeComboBox);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(horizontalSpacer_14);


        gridLayout->addLayout(hboxLayout1, 0, 1, 1, 1);

        label = new QLabel(groupBox_2);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        targetRateControlSpinBox = new QSpinBox(groupBox_2);
        targetRateControlSpinBox->setObjectName(QString::fromUtf8("targetRateControlSpinBox"));
        targetRateControlSpinBox->setMaximum(999999999);
        targetRateControlSpinBox->setValue(700);

        hboxLayout2->addWidget(targetRateControlSpinBox);

        targetRateControlLabel2 = new QLabel(groupBox_2);
        targetRateControlLabel2->setObjectName(QString::fromUtf8("targetRateControlLabel2"));

        hboxLayout2->addWidget(targetRateControlLabel2);

        spacer_5 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout2->addItem(spacer_5);


        gridLayout->addLayout(hboxLayout2, 1, 1, 1, 1);


        gridLayout_6->addLayout(gridLayout, 0, 0, 1, 1);

        verticalLayout_14 = new QVBoxLayout();
        verticalLayout_14->setObjectName(QString::fromUtf8("verticalLayout_14"));
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(12);
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(0);
        hboxLayout4->setObjectName(QString::fromUtf8("hboxLayout4"));
        quantiserLabel1 = new QLabel(groupBox_2);
        quantiserLabel1->setObjectName(QString::fromUtf8("quantiserLabel1"));
        quantiserLabel1->setEnabled(false);

        hboxLayout4->addWidget(quantiserLabel1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout4->addItem(spacerItem1);

        quantiserLabel2 = new QLabel(groupBox_2);
        quantiserLabel2->setObjectName(QString::fromUtf8("quantiserLabel2"));
        quantiserLabel2->setEnabled(false);

        hboxLayout4->addWidget(quantiserLabel2);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout4->addItem(spacerItem2);

        quantiserLabel3 = new QLabel(groupBox_2);
        quantiserLabel3->setObjectName(QString::fromUtf8("quantiserLabel3"));
        quantiserLabel3->setEnabled(false);

        hboxLayout4->addWidget(quantiserLabel3);


        vboxLayout->addLayout(hboxLayout4);

        quantiserSlider = new QSlider(groupBox_2);
        quantiserSlider->setObjectName(QString::fromUtf8("quantiserSlider"));
        quantiserSlider->setEnabled(false);
        quantiserSlider->setMinimumSize(QSize(375, 0));
        quantiserSlider->setMaximum(51);
        quantiserSlider->setPageStep(5);
        quantiserSlider->setValue(26);
        quantiserSlider->setOrientation(Qt::Horizontal);
        quantiserSlider->setTickPosition(QSlider::TicksBelow);

        vboxLayout->addWidget(quantiserSlider);


        hboxLayout3->addLayout(vboxLayout);

        quantiserSpinBox = new QSpinBox(groupBox_2);
        quantiserSpinBox->setObjectName(QString::fromUtf8("quantiserSpinBox"));
        quantiserSpinBox->setEnabled(false);
        quantiserSpinBox->setMaximum(51);
        quantiserSpinBox->setValue(26);

        hboxLayout3->addWidget(quantiserSpinBox);

        spacer_4 = new QSpacerItem(13, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacer_4);


        verticalLayout_14->addLayout(hboxLayout3);

        strictCbrCheckBox = new QCheckBox(groupBox_2);
        strictCbrCheckBox->setObjectName(QString::fromUtf8("strictCbrCheckBox"));
        strictCbrCheckBox->setEnabled(false);

        verticalLayout_14->addWidget(strictCbrCheckBox);

        horizontalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        verticalLayout_14->addItem(horizontalSpacer_3);


        gridLayout_6->addLayout(verticalLayout_14, 1, 0, 1, 1);


        verticalLayout_5->addWidget(groupBox_2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        tabWidget->addTab(tabGeneral, QString());
        tabAdvancedRC = new QWidget();
        tabAdvancedRC->setObjectName(QString::fromUtf8("tabAdvancedRC"));
        verticalLayout_12 = new QVBoxLayout(tabAdvancedRC);
        verticalLayout_12->setObjectName(QString::fromUtf8("verticalLayout_12"));
        groupBox_20 = new QGroupBox(tabAdvancedRC);
        groupBox_20->setObjectName(QString::fromUtf8("groupBox_20"));
        verticalLayout_13 = new QVBoxLayout(groupBox_20);
        verticalLayout_13->setObjectName(QString::fromUtf8("verticalLayout_13"));
        maxCrfCheckBox = new QCheckBox(groupBox_20);
        maxCrfCheckBox->setObjectName(QString::fromUtf8("maxCrfCheckBox"));

        verticalLayout_13->addWidget(maxCrfCheckBox);

        _16 = new QHBoxLayout();
        _16->setObjectName(QString::fromUtf8("_16"));
        horizontalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        _16->addItem(horizontalSpacer_4);

        _17 = new QHBoxLayout();
        _17->setSpacing(12);
        _17->setObjectName(QString::fromUtf8("_17"));
        _18 = new QVBoxLayout();
        _18->setSpacing(0);
        _18->setObjectName(QString::fromUtf8("_18"));
        _19 = new QHBoxLayout();
        _19->setSpacing(0);
        _19->setObjectName(QString::fromUtf8("_19"));
        quantiserLabel1_2 = new QLabel(groupBox_20);
        quantiserLabel1_2->setObjectName(QString::fromUtf8("quantiserLabel1_2"));
        quantiserLabel1_2->setEnabled(false);

        _19->addWidget(quantiserLabel1_2);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _19->addItem(spacerItem3);

        quantiserLabel2_2 = new QLabel(groupBox_20);
        quantiserLabel2_2->setObjectName(QString::fromUtf8("quantiserLabel2_2"));
        quantiserLabel2_2->setEnabled(false);

        _19->addWidget(quantiserLabel2_2);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _19->addItem(spacerItem4);

        quantiserLabel3_2 = new QLabel(groupBox_20);
        quantiserLabel3_2->setObjectName(QString::fromUtf8("quantiserLabel3_2"));
        quantiserLabel3_2->setEnabled(false);

        _19->addWidget(quantiserLabel3_2);


        _18->addLayout(_19);

        maxCrfSlider = new QSlider(groupBox_20);
        maxCrfSlider->setObjectName(QString::fromUtf8("maxCrfSlider"));
        maxCrfSlider->setEnabled(false);
        maxCrfSlider->setMinimumSize(QSize(375, 0));
        maxCrfSlider->setMaximum(51);
        maxCrfSlider->setPageStep(5);
        maxCrfSlider->setValue(26);
        maxCrfSlider->setOrientation(Qt::Horizontal);
        maxCrfSlider->setTickPosition(QSlider::TicksBelow);

        _18->addWidget(maxCrfSlider);


        _17->addLayout(_18);

        maxCrfSpinBox = new QSpinBox(groupBox_20);
        maxCrfSpinBox->setObjectName(QString::fromUtf8("maxCrfSpinBox"));
        maxCrfSpinBox->setEnabled(false);
        maxCrfSpinBox->setMaximum(51);
        maxCrfSpinBox->setValue(26);

        _17->addWidget(maxCrfSpinBox);


        _16->addLayout(_17);

        spacer_22 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _16->addItem(spacer_22);


        verticalLayout_13->addLayout(_16);

        cuTreeCheckBox = new QCheckBox(groupBox_20);
        cuTreeCheckBox->setObjectName(QString::fromUtf8("cuTreeCheckBox"));

        verticalLayout_13->addWidget(cuTreeCheckBox);

        _36 = new QHBoxLayout();
        _36->setObjectName(QString::fromUtf8("_36"));
        lblLookahead = new QLabel(groupBox_20);
        lblLookahead->setObjectName(QString::fromUtf8("lblLookahead"));

        _36->addWidget(lblLookahead);

        lookaheadSpinBox = new QSpinBox(groupBox_20);
        lookaheadSpinBox->setObjectName(QString::fromUtf8("lookaheadSpinBox"));
        lookaheadSpinBox->setMaximum(250);

        _36->addWidget(lookaheadSpinBox);

        lblLookaheadFrames = new QLabel(groupBox_20);
        lblLookaheadFrames->setObjectName(QString::fromUtf8("lblLookaheadFrames"));

        _36->addWidget(lblLookaheadFrames);

        spacer_3 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _36->addItem(spacer_3);


        verticalLayout_13->addLayout(_36);

        _20 = new QGridLayout();
        _20->setObjectName(QString::fromUtf8("_20"));
        label_55 = new QLabel(groupBox_20);
        label_55->setObjectName(QString::fromUtf8("label_55"));

        _20->addWidget(label_55, 0, 0, 1, 1);

        _22 = new QHBoxLayout();
        _22->setObjectName(QString::fromUtf8("_22"));
        spsiComboBox = new QComboBox(groupBox_20);
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->setObjectName(QString::fromUtf8("spsiComboBox"));

        _22->addWidget(spsiComboBox);

        spacer_63 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _22->addItem(spacer_63);


        _20->addLayout(_22, 0, 1, 1, 1);


        verticalLayout_13->addLayout(_20);


        verticalLayout_12->addWidget(groupBox_20);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_12->addItem(verticalSpacer_4);

        tabWidget->addTab(tabAdvancedRC, QString());
        tabMotion = new QWidget();
        tabMotion->setObjectName(QString::fromUtf8("tabMotion"));
        vboxLayout1 = new QVBoxLayout(tabMotion);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        groupBox_11 = new QGroupBox(tabMotion);
        groupBox_11->setObjectName(QString::fromUtf8("groupBox_11"));
        vboxLayout2 = new QVBoxLayout(groupBox_11);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setObjectName(QString::fromUtf8("hboxLayout5"));
        label_38 = new QLabel(groupBox_11);
        label_38->setObjectName(QString::fromUtf8("label_38"));

        hboxLayout5->addWidget(label_38);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setObjectName(QString::fromUtf8("hboxLayout6"));
        meMethodComboBox = new QComboBox(groupBox_11);
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->setObjectName(QString::fromUtf8("meMethodComboBox"));

        hboxLayout6->addWidget(meMethodComboBox);

        spacer_10 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout6->addItem(spacer_10);


        hboxLayout5->addLayout(hboxLayout6);


        vboxLayout2->addLayout(hboxLayout5);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setObjectName(QString::fromUtf8("hboxLayout7"));
        hboxLayout8 = new QHBoxLayout();
        hboxLayout8->setSpacing(12);
        hboxLayout8->setObjectName(QString::fromUtf8("hboxLayout8"));
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(0);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        hboxLayout9 = new QHBoxLayout();
        hboxLayout9->setSpacing(0);
        hboxLayout9->setObjectName(QString::fromUtf8("hboxLayout9"));
        label_35 = new QLabel(groupBox_11);
        label_35->setObjectName(QString::fromUtf8("label_35"));

        hboxLayout9->addWidget(label_35);

        spacer_11 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout9->addItem(spacer_11);

        label_36 = new QLabel(groupBox_11);
        label_36->setObjectName(QString::fromUtf8("label_36"));

        hboxLayout9->addWidget(label_36);

        spacer_13 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout9->addItem(spacer_13);

        label_37 = new QLabel(groupBox_11);
        label_37->setObjectName(QString::fromUtf8("label_37"));

        hboxLayout9->addWidget(label_37);


        vboxLayout3->addLayout(hboxLayout9);

        meSlider = new QSlider(groupBox_11);
        meSlider->setObjectName(QString::fromUtf8("meSlider"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(meSlider->sizePolicy().hasHeightForWidth());
        meSlider->setSizePolicy(sizePolicy);
        meSlider->setMinimumSize(QSize(375, 0));
        meSlider->setMinimum(1);
        meSlider->setMaximum(7);
        meSlider->setPageStep(1);
        meSlider->setValue(5);
        meSlider->setOrientation(Qt::Horizontal);
        meSlider->setTickPosition(QSlider::TicksBelow);

        vboxLayout3->addWidget(meSlider);


        hboxLayout8->addLayout(vboxLayout3);

        meSpinBox = new QSpinBox(groupBox_11);
        meSpinBox->setObjectName(QString::fromUtf8("meSpinBox"));
        meSpinBox->setMinimum(1);
        meSpinBox->setMaximum(7);
        meSpinBox->setValue(5);

        hboxLayout8->addWidget(meSpinBox);


        hboxLayout7->addLayout(hboxLayout8);

        spacer_12 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout7->addItem(spacer_12);


        vboxLayout2->addLayout(hboxLayout7);


        vboxLayout1->addWidget(groupBox_11);

        groupBox_19 = new QGroupBox(tabMotion);
        groupBox_19->setObjectName(QString::fromUtf8("groupBox_19"));
        vboxLayout4 = new QVBoxLayout(groupBox_19);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        hboxLayout10 = new QHBoxLayout();
        hboxLayout10->setObjectName(QString::fromUtf8("hboxLayout10"));
        mvRangeSpinBox = new QSpinBox(groupBox_19);
        mvRangeSpinBox->setObjectName(QString::fromUtf8("mvRangeSpinBox"));
        mvRangeSpinBox->setMaximum(64);
        mvRangeSpinBox->setValue(16);

        hboxLayout10->addWidget(mvRangeSpinBox);

        spacer_15 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout10->addItem(spacer_15);


        gridLayout1->addLayout(hboxLayout10, 0, 1, 1, 1);

        label_39 = new QLabel(groupBox_19);
        label_39->setObjectName(QString::fromUtf8("label_39"));

        gridLayout1->addWidget(label_39, 0, 0, 1, 1);


        vboxLayout4->addLayout(gridLayout1);


        vboxLayout1->addWidget(groupBox_19);

        groupBox_18 = new QGroupBox(tabMotion);
        groupBox_18->setObjectName(QString::fromUtf8("groupBox_18"));
        gridLayout2 = new QGridLayout(groupBox_18);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName(QString::fromUtf8("gridLayout3"));
        lblBPredict = new QLabel(groupBox_18);
        lblBPredict->setObjectName(QString::fromUtf8("lblBPredict"));

        gridLayout3->addWidget(lblBPredict, 0, 0, 1, 1);

        weightedPredictCheckBox = new QCheckBox(groupBox_18);
        weightedPredictCheckBox->setObjectName(QString::fromUtf8("weightedPredictCheckBox"));

        gridLayout3->addWidget(weightedPredictCheckBox, 0, 1, 1, 1);

        bIntraCheckBox = new QCheckBox(groupBox_18);
        bIntraCheckBox->setObjectName(QString::fromUtf8("bIntraCheckBox"));

        gridLayout3->addWidget(bIntraCheckBox, 0, 2, 1, 1);


        gridLayout2->addLayout(gridLayout3, 2, 0, 1, 1);

        constrainedIntraCheckBox = new QCheckBox(groupBox_18);
        constrainedIntraCheckBox->setObjectName(QString::fromUtf8("constrainedIntraCheckBox"));

        gridLayout2->addWidget(constrainedIntraCheckBox, 3, 0, 1, 1);

        hboxLayout11 = new QHBoxLayout();
        hboxLayout11->setObjectName(QString::fromUtf8("hboxLayout11"));
        lblMParts = new QLabel(groupBox_18);
        lblMParts->setObjectName(QString::fromUtf8("lblMParts"));

        hboxLayout11->addWidget(lblMParts);

        rectInterCheckBox = new QCheckBox(groupBox_18);
        rectInterCheckBox->setObjectName(QString::fromUtf8("rectInterCheckBox"));

        hboxLayout11->addWidget(rectInterCheckBox);

        AMPInterCheckBox = new QCheckBox(groupBox_18);
        AMPInterCheckBox->setObjectName(QString::fromUtf8("AMPInterCheckBox"));

        hboxLayout11->addWidget(AMPInterCheckBox);


        gridLayout2->addLayout(hboxLayout11, 4, 0, 1, 1);

        limitInterModesCheckBox = new QCheckBox(groupBox_18);
        limitInterModesCheckBox->setObjectName(QString::fromUtf8("limitInterModesCheckBox"));

        gridLayout2->addWidget(limitInterModesCheckBox, 5, 0, 1, 1);

        gridLayout4 = new QGridLayout();
        gridLayout4->setObjectName(QString::fromUtf8("gridLayout4"));
        lblWeightedPPredict = new QLabel(groupBox_18);
        lblWeightedPPredict->setObjectName(QString::fromUtf8("lblWeightedPPredict"));

        gridLayout4->addWidget(lblWeightedPPredict, 0, 0, 1, 1);

        hboxLayout12 = new QHBoxLayout();
        hboxLayout12->setObjectName(QString::fromUtf8("hboxLayout12"));
        weightedPPredictComboBox = new QComboBox(groupBox_18);
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->setObjectName(QString::fromUtf8("weightedPPredictComboBox"));

        hboxLayout12->addWidget(weightedPPredictComboBox);

        spacer_18 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout12->addItem(spacer_18);


        gridLayout4->addLayout(hboxLayout12, 0, 1, 1, 1);


        gridLayout2->addLayout(gridLayout4, 1, 0, 1, 1);


        vboxLayout1->addWidget(groupBox_18);

        spacer_19 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacer_19);

        tabWidget->addTab(tabMotion, QString());
        tabFrame = new QWidget();
        tabFrame->setObjectName(QString::fromUtf8("tabFrame"));
        verticalLayout_7 = new QVBoxLayout(tabFrame);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        groupBox_6 = new QGroupBox(tabFrame);
        groupBox_6->setObjectName(QString::fromUtf8("groupBox_6"));
        verticalLayout_3 = new QVBoxLayout(groupBox_6);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        loopFilterCheckBox = new QCheckBox(groupBox_6);
        loopFilterCheckBox->setObjectName(QString::fromUtf8("loopFilterCheckBox"));

        verticalLayout_3->addWidget(loopFilterCheckBox);

        openGopCheckBox = new QCheckBox(groupBox_6);
        openGopCheckBox->setObjectName(QString::fromUtf8("openGopCheckBox"));

        verticalLayout_3->addWidget(openGopCheckBox);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        interlacedCheckBox = new QCheckBox(groupBox_6);
        interlacedCheckBox->setObjectName(QString::fromUtf8("interlacedCheckBox"));

        gridLayout_2->addWidget(interlacedCheckBox, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        interlacedComboBox = new QComboBox(groupBox_6);
        interlacedComboBox->addItem(QString());
        interlacedComboBox->addItem(QString());
        interlacedComboBox->setObjectName(QString::fromUtf8("interlacedComboBox"));
        interlacedComboBox->setEnabled(false);

        horizontalLayout->addWidget(interlacedComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout, 1, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_2);

        _3 = new QHBoxLayout();
        _3->setObjectName(QString::fromUtf8("_3"));
        _3->setContentsMargins(0, -1, -1, -1);
        maxRefFramesLabel = new QLabel(groupBox_6);
        maxRefFramesLabel->setObjectName(QString::fromUtf8("maxRefFramesLabel"));

        _3->addWidget(maxRefFramesLabel);

        hboxLayout13 = new QHBoxLayout();
        hboxLayout13->setObjectName(QString::fromUtf8("hboxLayout13"));
        refFramesSpinBox = new QSpinBox(groupBox_6);
        refFramesSpinBox->setObjectName(QString::fromUtf8("refFramesSpinBox"));
        refFramesSpinBox->setMinimum(1);
        refFramesSpinBox->setMaximum(16);

        hboxLayout13->addWidget(refFramesSpinBox);

        spacer_24 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout13->addItem(spacer_24);


        _3->addLayout(hboxLayout13);

        refLimitLabel = new QLabel(groupBox_6);
        refLimitLabel->setObjectName(QString::fromUtf8("refLimitLabel"));

        _3->addWidget(refLimitLabel);

        limitRefCUCheckBox = new QCheckBox(groupBox_6);
        limitRefCUCheckBox->setObjectName(QString::fromUtf8("limitRefCUCheckBox"));

        _3->addWidget(limitRefCUCheckBox);

        limitRefDepthCheckBox = new QCheckBox(groupBox_6);
        limitRefDepthCheckBox->setObjectName(QString::fromUtf8("limitRefDepthCheckBox"));

        _3->addWidget(limitRefDepthCheckBox);


        verticalLayout_3->addLayout(_3);


        verticalLayout_7->addWidget(groupBox_6);

        groupBoxBframes = new QGroupBox(tabFrame);
        groupBoxBframes->setObjectName(QString::fromUtf8("groupBoxBframes"));
        gridLayout5 = new QGridLayout(groupBoxBframes);
        gridLayout5->setObjectName(QString::fromUtf8("gridLayout5"));
        label_31 = new QLabel(groupBoxBframes);
        label_31->setObjectName(QString::fromUtf8("label_31"));

        gridLayout5->addWidget(label_31, 0, 0, 1, 1);

        hboxLayout14 = new QHBoxLayout();
        hboxLayout14->setObjectName(QString::fromUtf8("hboxLayout14"));
        maxBFramesSpinBox = new QSpinBox(groupBoxBframes);
        maxBFramesSpinBox->setObjectName(QString::fromUtf8("maxBFramesSpinBox"));
        maxBFramesSpinBox->setMaximum(16);

        hboxLayout14->addWidget(maxBFramesSpinBox);

        spacer_25 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout14->addItem(spacer_25);


        gridLayout5->addLayout(hboxLayout14, 0, 1, 1, 1);

        label_29 = new QLabel(groupBoxBframes);
        label_29->setObjectName(QString::fromUtf8("label_29"));

        gridLayout5->addWidget(label_29, 1, 0, 1, 1);

        hboxLayout15 = new QHBoxLayout();
        hboxLayout15->setObjectName(QString::fromUtf8("hboxLayout15"));
        BFrameBiasSpinBox = new QSpinBox(groupBoxBframes);
        BFrameBiasSpinBox->setObjectName(QString::fromUtf8("BFrameBiasSpinBox"));
        BFrameBiasSpinBox->setMinimum(-100);
        BFrameBiasSpinBox->setMaximum(100);

        hboxLayout15->addWidget(BFrameBiasSpinBox);

        spacer_26 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout15->addItem(spacer_26);


        gridLayout5->addLayout(hboxLayout15, 1, 1, 1, 1);

        label_4 = new QLabel(groupBoxBframes);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout5->addWidget(label_4, 2, 0, 1, 1);

        hboxLayout16 = new QHBoxLayout();
        hboxLayout16->setObjectName(QString::fromUtf8("hboxLayout16"));
        adaptiveBFrameComboBox = new QComboBox(groupBoxBframes);
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->setObjectName(QString::fromUtf8("adaptiveBFrameComboBox"));

        hboxLayout16->addWidget(adaptiveBFrameComboBox);

        spacer_27 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout16->addItem(spacer_27);


        gridLayout5->addLayout(hboxLayout16, 2, 1, 1, 1);

        label_33 = new QLabel(groupBoxBframes);
        label_33->setObjectName(QString::fromUtf8("label_33"));

        gridLayout5->addWidget(label_33, 3, 0, 1, 1);

        hboxLayout17 = new QHBoxLayout();
        hboxLayout17->setObjectName(QString::fromUtf8("hboxLayout17"));
        bFrameRefComboBox = new QComboBox(groupBoxBframes);
        bFrameRefComboBox->addItem(QString());
        bFrameRefComboBox->addItem(QString());
        bFrameRefComboBox->setObjectName(QString::fromUtf8("bFrameRefComboBox"));

        hboxLayout17->addWidget(bFrameRefComboBox);

        spacer_28 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout17->addItem(spacer_28);


        gridLayout5->addLayout(hboxLayout17, 3, 1, 1, 1);


        verticalLayout_7->addWidget(groupBoxBframes);

        groupBox_8 = new QGroupBox(tabFrame);
        groupBox_8->setObjectName(QString::fromUtf8("groupBox_8"));
        verticalLayout_6 = new QVBoxLayout(groupBox_8);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label_34 = new QLabel(groupBox_8);
        label_34->setObjectName(QString::fromUtf8("label_34"));

        gridLayout_3->addWidget(label_34, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_28 = new QLabel(groupBox_8);
        label_28->setObjectName(QString::fromUtf8("label_28"));

        horizontalLayout_2->addWidget(label_28);

        minGopSizeSpinBox = new QSpinBox(groupBox_8);
        minGopSizeSpinBox->setObjectName(QString::fromUtf8("minGopSizeSpinBox"));
        minGopSizeSpinBox->setMaximum(100);
        minGopSizeSpinBox->setValue(25);

        horizontalLayout_2->addWidget(minGopSizeSpinBox);

        spacer_29 = new QSpacerItem(10, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacer_29);

        label_26 = new QLabel(groupBox_8);
        label_26->setObjectName(QString::fromUtf8("label_26"));

        horizontalLayout_2->addWidget(label_26);

        maxGopSizeSpinBox = new QSpinBox(groupBox_8);
        maxGopSizeSpinBox->setObjectName(QString::fromUtf8("maxGopSizeSpinBox"));
        maxGopSizeSpinBox->setMaximum(1000);
        maxGopSizeSpinBox->setValue(250);

        horizontalLayout_2->addWidget(maxGopSizeSpinBox);

        spacer_30 = new QSpacerItem(168, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacer_30);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        label_27 = new QLabel(groupBox_8);
        label_27->setObjectName(QString::fromUtf8("label_27"));

        gridLayout_3->addWidget(label_27, 1, 0, 1, 1);

        hboxLayout18 = new QHBoxLayout();
        hboxLayout18->setObjectName(QString::fromUtf8("hboxLayout18"));
        IFrameThresholdSpinBox = new QSpinBox(groupBox_8);
        IFrameThresholdSpinBox->setObjectName(QString::fromUtf8("IFrameThresholdSpinBox"));
        IFrameThresholdSpinBox->setMaximum(100);
        IFrameThresholdSpinBox->setValue(40);

        hboxLayout18->addWidget(IFrameThresholdSpinBox);

        spacer_31 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout18->addItem(spacer_31);


        gridLayout_3->addLayout(hboxLayout18, 1, 1, 1, 1);


        verticalLayout_6->addLayout(gridLayout_3);


        verticalLayout_7->addWidget(groupBox_8);

        spacer_32 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_7->addItem(spacer_32);

        tabWidget->addTab(tabFrame, QString());
        tabAnalysis = new QWidget();
        tabAnalysis->setObjectName(QString::fromUtf8("tabAnalysis"));
        vboxLayout5 = new QVBoxLayout(tabAnalysis);
        vboxLayout5->setObjectName(QString::fromUtf8("vboxLayout5"));
        groupBox_12 = new QGroupBox(tabAnalysis);
        groupBox_12->setObjectName(QString::fromUtf8("groupBox_12"));
        verticalLayout_10 = new QVBoxLayout(groupBox_12);
        verticalLayout_10->setObjectName(QString::fromUtf8("verticalLayout_10"));
        fastPSkipCheckBox = new QCheckBox(groupBox_12);
        fastPSkipCheckBox->setObjectName(QString::fromUtf8("fastPSkipCheckBox"));

        verticalLayout_10->addWidget(fastPSkipCheckBox);

        dctDecimateCheckBox = new QCheckBox(groupBox_12);
        dctDecimateCheckBox->setObjectName(QString::fromUtf8("dctDecimateCheckBox"));

        verticalLayout_10->addWidget(dctDecimateCheckBox);

        gridLayout6 = new QGridLayout();
        gridLayout6->setObjectName(QString::fromUtf8("gridLayout6"));
        lblRDO = new QLabel(groupBox_12);
        lblRDO->setObjectName(QString::fromUtf8("lblRDO"));

        gridLayout6->addWidget(lblRDO, 0, 0, 1, 1);

        hboxLayout19 = new QHBoxLayout();
        hboxLayout19->setObjectName(QString::fromUtf8("hboxLayout19"));
        spacerItem5 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout19->addItem(spacerItem5);

        lblPsychoRDO = new QLabel(groupBox_12);
        lblPsychoRDO->setObjectName(QString::fromUtf8("lblPsychoRDO"));

        hboxLayout19->addWidget(lblPsychoRDO);

        rdoSpinBox = new QSpinBox(groupBox_12);
        rdoSpinBox->setObjectName(QString::fromUtf8("rdoSpinBox"));
        rdoSpinBox->setMinimum(1);
        rdoSpinBox->setMaximum(6);

        hboxLayout19->addWidget(rdoSpinBox);

        spacerItem6 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout19->addItem(spacerItem6);


        gridLayout6->addLayout(hboxLayout19, 0, 1, 1, 1);

        hboxLayout20 = new QHBoxLayout();
        hboxLayout20->setObjectName(QString::fromUtf8("hboxLayout20"));
        lblRDOPsyVS = new QLabel(groupBox_12);
        lblRDOPsyVS->setObjectName(QString::fromUtf8("lblRDOPsyVS"));

        hboxLayout20->addWidget(lblRDOPsyVS);

        psychoRdoSpinBox = new QDoubleSpinBox(groupBox_12);
        psychoRdoSpinBox->setObjectName(QString::fromUtf8("psychoRdoSpinBox"));
        psychoRdoSpinBox->setMaximum(10.000000000000000);
        psychoRdoSpinBox->setSingleStep(0.100000000000000);

        hboxLayout20->addWidget(psychoRdoSpinBox);

        spacerItem7 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout20->addItem(spacerItem7);


        gridLayout6->addLayout(hboxLayout20, 0, 2, 1, 1);

        lblRDOQ = new QLabel(groupBox_12);
        lblRDOQ->setObjectName(QString::fromUtf8("lblRDOQ"));

        gridLayout6->addWidget(lblRDOQ, 1, 0, 1, 1);

        hboxLayout21 = new QHBoxLayout();
        hboxLayout21->setObjectName(QString::fromUtf8("hboxLayout21"));
        spacerItem8 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout21->addItem(spacerItem8);

        lblRDOQLevel = new QLabel(groupBox_12);
        lblRDOQLevel->setObjectName(QString::fromUtf8("lblRDOQLevel"));

        hboxLayout21->addWidget(lblRDOQLevel);

        rdoqSpinBox = new QSpinBox(groupBox_12);
        rdoqSpinBox->setObjectName(QString::fromUtf8("rdoqSpinBox"));
        rdoqSpinBox->setMinimum(0);
        rdoqSpinBox->setMaximum(2);

        hboxLayout21->addWidget(rdoqSpinBox);

        spacerItem9 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout21->addItem(spacerItem9);


        gridLayout6->addLayout(hboxLayout21, 1, 1, 1, 1);

        hboxLayout22 = new QHBoxLayout();
        hboxLayout22->setObjectName(QString::fromUtf8("hboxLayout22"));
        lblPsyRDOQ = new QLabel(groupBox_12);
        lblPsyRDOQ->setObjectName(QString::fromUtf8("lblPsyRDOQ"));

        hboxLayout22->addWidget(lblPsyRDOQ);

        psychoRdoqSpinBox = new QDoubleSpinBox(groupBox_12);
        psychoRdoqSpinBox->setObjectName(QString::fromUtf8("psychoRdoqSpinBox"));
        psychoRdoqSpinBox->setMaximum(50.000000000000000);
        psychoRdoqSpinBox->setSingleStep(0.100000000000000);

        hboxLayout22->addWidget(psychoRdoqSpinBox);

        spacerItem10 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout22->addItem(spacerItem10);


        gridLayout6->addLayout(hboxLayout22, 1, 2, 1, 1);


        verticalLayout_10->addLayout(gridLayout6);

        gridLayout_8 = new QGridLayout();
        gridLayout_8->setObjectName(QString::fromUtf8("gridLayout_8"));
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        label_15 = new QLabel(groupBox_12);
        label_15->setObjectName(QString::fromUtf8("label_15"));

        horizontalLayout_8->addWidget(label_15);

        noiseReductionIntraSpinBox = new QSpinBox(groupBox_12);
        noiseReductionIntraSpinBox->setObjectName(QString::fromUtf8("noiseReductionIntraSpinBox"));
        noiseReductionIntraSpinBox->setMaximum(2000);

        horizontalLayout_8->addWidget(noiseReductionIntraSpinBox);

        label_16 = new QLabel(groupBox_12);
        label_16->setObjectName(QString::fromUtf8("label_16"));

        horizontalLayout_8->addWidget(label_16);

        noiseReductionInterSpinBox = new QSpinBox(groupBox_12);
        noiseReductionInterSpinBox->setObjectName(QString::fromUtf8("noiseReductionInterSpinBox"));
        noiseReductionInterSpinBox->setMaximum(2000);

        horizontalLayout_8->addWidget(noiseReductionInterSpinBox);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_6);


        gridLayout_8->addLayout(horizontalLayout_8, 0, 0, 1, 1);


        verticalLayout_10->addLayout(gridLayout_8);

        strongIntraSmoothingCheckBox = new QCheckBox(groupBox_12);
        strongIntraSmoothingCheckBox->setObjectName(QString::fromUtf8("strongIntraSmoothingCheckBox"));

        verticalLayout_10->addWidget(strongIntraSmoothingCheckBox);


        vboxLayout5->addWidget(groupBox_12);

        groupBoxQuantMatrix = new QGroupBox(tabAnalysis);
        groupBoxQuantMatrix->setObjectName(QString::fromUtf8("groupBoxQuantMatrix"));
        vboxLayout6 = new QVBoxLayout(groupBoxQuantMatrix);
        vboxLayout6->setObjectName(QString::fromUtf8("vboxLayout6"));
        vboxLayout7 = new QVBoxLayout();
        vboxLayout7->setObjectName(QString::fromUtf8("vboxLayout7"));
        matrixFlatRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixFlatRadioButton->setObjectName(QString::fromUtf8("matrixFlatRadioButton"));
        matrixFlatRadioButton->setChecked(true);

        vboxLayout7->addWidget(matrixFlatRadioButton);

        matrixJvtRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixJvtRadioButton->setObjectName(QString::fromUtf8("matrixJvtRadioButton"));

        vboxLayout7->addWidget(matrixJvtRadioButton);

        hboxLayout23 = new QHBoxLayout();
        hboxLayout23->setObjectName(QString::fromUtf8("hboxLayout23"));
        matrixCustomRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixCustomRadioButton->setObjectName(QString::fromUtf8("matrixCustomRadioButton"));

        hboxLayout23->addWidget(matrixCustomRadioButton);

        matrixCustomEditButton = new QPushButton(groupBoxQuantMatrix);
        matrixCustomEditButton->setObjectName(QString::fromUtf8("matrixCustomEditButton"));
        matrixCustomEditButton->setEnabled(false);

        hboxLayout23->addWidget(matrixCustomEditButton);

        spacer_38 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout23->addItem(spacer_38);


        vboxLayout7->addLayout(hboxLayout23);


        vboxLayout6->addLayout(vboxLayout7);


        vboxLayout5->addWidget(groupBoxQuantMatrix);

        spacer_39 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout5->addItem(spacer_39);

        tabWidget->addTab(tabAnalysis, QString());
        tabQuantiser = new QWidget();
        tabQuantiser->setObjectName(QString::fromUtf8("tabQuantiser"));
        verticalLayout_9 = new QVBoxLayout(tabQuantiser);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        groupBox_4 = new QGroupBox(tabQuantiser);
        groupBox_4->setObjectName(QString::fromUtf8("groupBox_4"));
        vboxLayout8 = new QVBoxLayout(groupBox_4);
        vboxLayout8->setObjectName(QString::fromUtf8("vboxLayout8"));
        gridLayout7 = new QGridLayout();
        gridLayout7->setObjectName(QString::fromUtf8("gridLayout7"));
        label_20 = new QLabel(groupBox_4);
        label_20->setObjectName(QString::fromUtf8("label_20"));

        gridLayout7->addWidget(label_20, 3, 0, 1, 1);

        hboxLayout24 = new QHBoxLayout();
        hboxLayout24->setObjectName(QString::fromUtf8("hboxLayout24"));
        quantiserMaxStepSpinBox = new QSpinBox(groupBox_4);
        quantiserMaxStepSpinBox->setObjectName(QString::fromUtf8("quantiserMaxStepSpinBox"));
        quantiserMaxStepSpinBox->setMaximum(10);
        quantiserMaxStepSpinBox->setValue(4);

        hboxLayout24->addWidget(quantiserMaxStepSpinBox);

        spacer_42 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout24->addItem(spacer_42);


        gridLayout7->addLayout(hboxLayout24, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_4);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout7->addWidget(label_6, 1, 0, 1, 1);

        hboxLayout25 = new QHBoxLayout();
        hboxLayout25->setObjectName(QString::fromUtf8("hboxLayout25"));
        quantiserPbRatioSpinBox = new QDoubleSpinBox(groupBox_4);
        quantiserPbRatioSpinBox->setObjectName(QString::fromUtf8("quantiserPbRatioSpinBox"));
        quantiserPbRatioSpinBox->setDecimals(1);
        quantiserPbRatioSpinBox->setMinimum(1.000000000000000);
        quantiserPbRatioSpinBox->setMaximum(10.000000000000000);
        quantiserPbRatioSpinBox->setSingleStep(0.100000000000000);
        quantiserPbRatioSpinBox->setValue(1.300000000000000);

        hboxLayout25->addWidget(quantiserPbRatioSpinBox);

        spacer_44 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout25->addItem(spacer_44);


        gridLayout7->addLayout(hboxLayout25, 2, 1, 1, 1);

        label_17 = new QLabel(groupBox_4);
        label_17->setObjectName(QString::fromUtf8("label_17"));

        gridLayout7->addWidget(label_17, 0, 0, 1, 1);

        hboxLayout26 = new QHBoxLayout();
        hboxLayout26->setObjectName(QString::fromUtf8("hboxLayout26"));
        cbChromaLumaOffsetSpinBox = new QSpinBox(groupBox_4);
        cbChromaLumaOffsetSpinBox->setObjectName(QString::fromUtf8("cbChromaLumaOffsetSpinBox"));
        cbChromaLumaOffsetSpinBox->setMinimum(-12);
        cbChromaLumaOffsetSpinBox->setMaximum(12);

        hboxLayout26->addWidget(cbChromaLumaOffsetSpinBox);

        label_40 = new QLabel(groupBox_4);
        label_40->setObjectName(QString::fromUtf8("label_40"));

        hboxLayout26->addWidget(label_40);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout26->addItem(horizontalSpacer_13);

        crChromaLumaOffsetSpinBox = new QSpinBox(groupBox_4);
        crChromaLumaOffsetSpinBox->setObjectName(QString::fromUtf8("crChromaLumaOffsetSpinBox"));

        hboxLayout26->addWidget(crChromaLumaOffsetSpinBox);

        label_54 = new QLabel(groupBox_4);
        label_54->setObjectName(QString::fromUtf8("label_54"));

        hboxLayout26->addWidget(label_54);

        spacer_41 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout26->addItem(spacer_41);


        gridLayout7->addLayout(hboxLayout26, 3, 1, 1, 1);

        label_7 = new QLabel(groupBox_4);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout7->addWidget(label_7, 2, 0, 1, 1);

        hboxLayout27 = new QHBoxLayout();
        hboxLayout27->setObjectName(QString::fromUtf8("hboxLayout27"));
        quantiserIpRatioSpinBox = new QDoubleSpinBox(groupBox_4);
        quantiserIpRatioSpinBox->setObjectName(QString::fromUtf8("quantiserIpRatioSpinBox"));
        quantiserIpRatioSpinBox->setDecimals(1);
        quantiserIpRatioSpinBox->setMinimum(1.000000000000000);
        quantiserIpRatioSpinBox->setMaximum(10.000000000000000);
        quantiserIpRatioSpinBox->setSingleStep(0.100000000000000);
        quantiserIpRatioSpinBox->setValue(1.400000000000000);

        hboxLayout27->addWidget(quantiserIpRatioSpinBox);

        spacer_43 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout27->addItem(spacer_43);


        gridLayout7->addLayout(hboxLayout27, 1, 1, 1, 1);


        vboxLayout8->addLayout(gridLayout7);


        verticalLayout_9->addWidget(groupBox_4);

        groupBoxQuantCurveCompress = new QGroupBox(tabQuantiser);
        groupBoxQuantCurveCompress->setObjectName(QString::fromUtf8("groupBoxQuantCurveCompress"));
        vboxLayout9 = new QVBoxLayout(groupBoxQuantCurveCompress);
        vboxLayout9->setObjectName(QString::fromUtf8("vboxLayout9"));
        hboxLayout28 = new QHBoxLayout();
        hboxLayout28->setObjectName(QString::fromUtf8("hboxLayout28"));
        label_8 = new QLabel(groupBoxQuantCurveCompress);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        hboxLayout28->addWidget(label_8);

        hboxLayout29 = new QHBoxLayout();
        hboxLayout29->setObjectName(QString::fromUtf8("hboxLayout29"));
        quantiserCurveCompressSpinBox = new QSpinBox(groupBoxQuantCurveCompress);
        quantiserCurveCompressSpinBox->setObjectName(QString::fromUtf8("quantiserCurveCompressSpinBox"));
        quantiserCurveCompressSpinBox->setMaximum(100);
        quantiserCurveCompressSpinBox->setValue(60);

        hboxLayout29->addWidget(quantiserCurveCompressSpinBox);

        label_18 = new QLabel(groupBoxQuantCurveCompress);
        label_18->setObjectName(QString::fromUtf8("label_18"));

        hboxLayout29->addWidget(label_18);

        spacer_49 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout29->addItem(spacer_49);


        hboxLayout28->addLayout(hboxLayout29);


        vboxLayout9->addLayout(hboxLayout28);

        gridLayout8 = new QGridLayout();
        gridLayout8->setObjectName(QString::fromUtf8("gridLayout8"));
        label_21 = new QLabel(groupBoxQuantCurveCompress);
        label_21->setObjectName(QString::fromUtf8("label_21"));

        gridLayout8->addWidget(label_21, 0, 0, 1, 1);

        hboxLayout30 = new QHBoxLayout();
        hboxLayout30->setObjectName(QString::fromUtf8("hboxLayout30"));
        quantiserBeforeCompressSpinBox = new QDoubleSpinBox(groupBoxQuantCurveCompress);
        quantiserBeforeCompressSpinBox->setObjectName(QString::fromUtf8("quantiserBeforeCompressSpinBox"));
        quantiserBeforeCompressSpinBox->setDecimals(1);
        quantiserBeforeCompressSpinBox->setMaximum(999.000000000000000);
        quantiserBeforeCompressSpinBox->setValue(20.000000000000000);

        hboxLayout30->addWidget(quantiserBeforeCompressSpinBox);

        spacer_50 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout30->addItem(spacer_50);


        gridLayout8->addLayout(hboxLayout30, 0, 1, 1, 1);

        hboxLayout31 = new QHBoxLayout();
        hboxLayout31->setObjectName(QString::fromUtf8("hboxLayout31"));
        quantiserAfterCompressSpinBox = new QDoubleSpinBox(groupBoxQuantCurveCompress);
        quantiserAfterCompressSpinBox->setObjectName(QString::fromUtf8("quantiserAfterCompressSpinBox"));
        quantiserAfterCompressSpinBox->setDecimals(1);
        quantiserAfterCompressSpinBox->setMaximum(1.000000000000000);
        quantiserAfterCompressSpinBox->setSingleStep(0.100000000000000);
        quantiserAfterCompressSpinBox->setValue(0.500000000000000);

        hboxLayout31->addWidget(quantiserAfterCompressSpinBox);

        spacer_48 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout31->addItem(spacer_48);


        gridLayout8->addLayout(hboxLayout31, 1, 1, 1, 1);

        label_22 = new QLabel(groupBoxQuantCurveCompress);
        label_22->setObjectName(QString::fromUtf8("label_22"));

        gridLayout8->addWidget(label_22, 1, 0, 1, 1);


        vboxLayout9->addLayout(gridLayout8);


        verticalLayout_9->addWidget(groupBoxQuantCurveCompress);

        aqGroupBox = new QGroupBox(tabQuantiser);
        aqGroupBox->setObjectName(QString::fromUtf8("aqGroupBox"));
        verticalLayout_8 = new QVBoxLayout(aqGroupBox);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        aqVarianceCheckBox = new QCheckBox(aqGroupBox);
        aqVarianceCheckBox->setObjectName(QString::fromUtf8("aqVarianceCheckBox"));

        gridLayout_4->addWidget(aqVarianceCheckBox, 0, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        aqAlgoComboBox = new QComboBox(aqGroupBox);
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->setObjectName(QString::fromUtf8("aqAlgoComboBox"));
        aqAlgoComboBox->setEnabled(false);

        horizontalLayout_6->addWidget(aqAlgoComboBox);

        spacer_47 = new QSpacerItem(208, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(spacer_47);


        gridLayout_4->addLayout(horizontalLayout_6, 0, 1, 1, 1);

        aqStrengthLabel = new QLabel(aqGroupBox);
        aqStrengthLabel->setObjectName(QString::fromUtf8("aqStrengthLabel"));
        aqStrengthLabel->setEnabled(false);

        gridLayout_4->addWidget(aqStrengthLabel, 1, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        aqStrengthSpinBox = new QDoubleSpinBox(aqGroupBox);
        aqStrengthSpinBox->setObjectName(QString::fromUtf8("aqStrengthSpinBox"));
        aqStrengthSpinBox->setEnabled(false);
        aqStrengthSpinBox->setDecimals(2);
        aqStrengthSpinBox->setMinimum(0.500000000000000);
        aqStrengthSpinBox->setMaximum(1.500000000000000);
        aqStrengthSpinBox->setSingleStep(0.100000000000000);
        aqStrengthSpinBox->setValue(1.000000000000000);

        horizontalLayout_7->addWidget(aqStrengthSpinBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout_4->addLayout(horizontalLayout_7, 1, 1, 1, 1);


        verticalLayout_8->addLayout(gridLayout_4);


        verticalLayout_9->addWidget(aqGroupBox);

        spacer_52 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_9->addItem(spacer_52);

        tabWidget->addTab(tabQuantiser, QString());
        tabDispaly = new QWidget();
        tabDispaly->setObjectName(QString::fromUtf8("tabDispaly"));
        verticalLayout_11 = new QVBoxLayout(tabDispaly);
        verticalLayout_11->setObjectName(QString::fromUtf8("verticalLayout_11"));
        groupColor = new QGroupBox(tabDispaly);
        groupColor->setObjectName(QString::fromUtf8("groupColor"));
        gridLayout9 = new QGridLayout(groupColor);
        gridLayout9->setObjectName(QString::fromUtf8("gridLayout9"));
        label_50 = new QLabel(groupColor);
        label_50->setObjectName(QString::fromUtf8("label_50"));

        gridLayout9->addWidget(label_50, 0, 0, 1, 1);

        _8 = new QHBoxLayout();
        _8->setObjectName(QString::fromUtf8("_8"));
        videoFormatComboBox = new QComboBox(groupColor);
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->setObjectName(QString::fromUtf8("videoFormatComboBox"));

        _8->addWidget(videoFormatComboBox);

        spacer_68 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _8->addItem(spacer_68);


        gridLayout9->addLayout(_8, 0, 1, 1, 1);

        label_19 = new QLabel(groupColor);
        label_19->setObjectName(QString::fromUtf8("label_19"));

        gridLayout9->addWidget(label_19, 1, 0, 1, 1);

        _9 = new QHBoxLayout();
        _9->setObjectName(QString::fromUtf8("_9"));
        colourPrimariesComboBox = new QComboBox(groupColor);
        colourPrimariesComboBox->setObjectName(QString::fromUtf8("colourPrimariesComboBox"));

        _9->addWidget(colourPrimariesComboBox);

        spacer_69 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _9->addItem(spacer_69);


        gridLayout9->addLayout(_9, 1, 1, 1, 1);

        label_48 = new QLabel(groupColor);
        label_48->setObjectName(QString::fromUtf8("label_48"));

        gridLayout9->addWidget(label_48, 2, 0, 1, 1);

        _5 = new QHBoxLayout();
        _5->setObjectName(QString::fromUtf8("_5"));
        transferCharacteristicsComboBox = new QComboBox(groupColor);
        transferCharacteristicsComboBox->setObjectName(QString::fromUtf8("transferCharacteristicsComboBox"));

        _5->addWidget(transferCharacteristicsComboBox);

        spacer_67 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _5->addItem(spacer_67);


        gridLayout9->addLayout(_5, 2, 1, 1, 1);

        label_47 = new QLabel(groupColor);
        label_47->setObjectName(QString::fromUtf8("label_47"));

        gridLayout9->addWidget(label_47, 3, 0, 1, 1);

        _7 = new QHBoxLayout();
        _7->setObjectName(QString::fromUtf8("_7"));
        colourMatrixComboBox = new QComboBox(groupColor);
        colourMatrixComboBox->setObjectName(QString::fromUtf8("colourMatrixComboBox"));

        _7->addWidget(colourMatrixComboBox);

        spacer_71 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _7->addItem(spacer_71);


        gridLayout9->addLayout(_7, 3, 1, 1, 1);


        verticalLayout_11->addWidget(groupColor);

        groupBoxPAR = new QGroupBox(tabDispaly);
        groupBoxPAR->setObjectName(QString::fromUtf8("groupBoxPAR"));
        vboxLayout10 = new QVBoxLayout(groupBoxPAR);
        vboxLayout10->setObjectName(QString::fromUtf8("vboxLayout10"));
        labelPAR = new QLabel(groupBoxPAR);
        labelPAR->setObjectName(QString::fromUtf8("labelPAR"));
        labelPAR->setWordWrap(true);

        vboxLayout10->addWidget(labelPAR);

        gridLayout10 = new QGridLayout();
        gridLayout10->setObjectName(QString::fromUtf8("gridLayout10"));
        sarUnspecifiedRadioButton = new QRadioButton(groupBoxPAR);
        sarUnspecifiedRadioButton->setObjectName(QString::fromUtf8("sarUnspecifiedRadioButton"));
        sarUnspecifiedRadioButton->setChecked(true);

        gridLayout10->addWidget(sarUnspecifiedRadioButton, 0, 0, 1, 1);

        sarPredefinedRadioButton = new QRadioButton(groupBoxPAR);
        sarPredefinedRadioButton->setObjectName(QString::fromUtf8("sarPredefinedRadioButton"));

        gridLayout10->addWidget(sarPredefinedRadioButton, 1, 0, 1, 1);

        hboxLayout32 = new QHBoxLayout();
        hboxLayout32->setObjectName(QString::fromUtf8("hboxLayout32"));
        sarPredefinedComboBox = new QComboBox(groupBoxPAR);
        sarPredefinedComboBox->setObjectName(QString::fromUtf8("sarPredefinedComboBox"));
        sarPredefinedComboBox->setEnabled(false);

        hboxLayout32->addWidget(sarPredefinedComboBox);

        spacer_62 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout32->addItem(spacer_62);


        gridLayout10->addLayout(hboxLayout32, 1, 1, 1, 1);

        sarCustomRadioButton = new QRadioButton(groupBoxPAR);
        sarCustomRadioButton->setObjectName(QString::fromUtf8("sarCustomRadioButton"));

        gridLayout10->addWidget(sarCustomRadioButton, 2, 0, 1, 1);

        hboxLayout33 = new QHBoxLayout();
        hboxLayout33->setObjectName(QString::fromUtf8("hboxLayout33"));
        sarCustomSpinBox1 = new QSpinBox(groupBoxPAR);
        sarCustomSpinBox1->setObjectName(QString::fromUtf8("sarCustomSpinBox1"));
        sarCustomSpinBox1->setMinimum(1);
        sarCustomSpinBox1->setMaximum(9999);
        sarCustomSpinBox1->setValue(1);

        hboxLayout33->addWidget(sarCustomSpinBox1);

        sarCustomLabel = new QLabel(groupBoxPAR);
        sarCustomLabel->setObjectName(QString::fromUtf8("sarCustomLabel"));

        hboxLayout33->addWidget(sarCustomLabel);

        sarCustomSpinBox2 = new QSpinBox(groupBoxPAR);
        sarCustomSpinBox2->setObjectName(QString::fromUtf8("sarCustomSpinBox2"));
        sarCustomSpinBox2->setMinimum(1);
        sarCustomSpinBox2->setMaximum(9999);
        sarCustomSpinBox2->setValue(1);

        hboxLayout33->addWidget(sarCustomSpinBox2);

        spacer_64 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout33->addItem(spacer_64);


        gridLayout10->addLayout(hboxLayout33, 2, 1, 1, 1);

        sarAsInputRadioButton = new QRadioButton(groupBoxPAR);
        sarAsInputRadioButton->setObjectName(QString::fromUtf8("sarAsInputRadioButton"));

        gridLayout10->addWidget(sarAsInputRadioButton, 3, 0, 1, 1);


        vboxLayout10->addLayout(gridLayout10);


        verticalLayout_11->addWidget(groupBoxPAR);

        spacerItem11 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_11->addItem(spacerItem11);

        tabWidget->addTab(tabDispaly, QString());
        tabAdvanced1 = new QWidget();
        tabAdvanced1->setObjectName(QString::fromUtf8("tabAdvanced1"));
        vboxLayout11 = new QVBoxLayout(tabAdvanced1);
        vboxLayout11->setObjectName(QString::fromUtf8("vboxLayout11"));
        groupBox = new QGroupBox(tabAdvanced1);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        vboxLayout12 = new QVBoxLayout(groupBox);
        vboxLayout12->setObjectName(QString::fromUtf8("vboxLayout12"));
        gridLayout11 = new QGridLayout();
        gridLayout11->setObjectName(QString::fromUtf8("gridLayout11"));
        label_9 = new QLabel(groupBox);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout11->addWidget(label_9, 0, 0, 1, 1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName(QString::fromUtf8("label_14"));

        gridLayout11->addWidget(label_14, 2, 0, 1, 1);

        hboxLayout34 = new QHBoxLayout();
        hboxLayout34->setObjectName(QString::fromUtf8("hboxLayout34"));
        vbvBufferSizeSpinBox = new QSpinBox(groupBox);
        vbvBufferSizeSpinBox->setObjectName(QString::fromUtf8("vbvBufferSizeSpinBox"));
        vbvBufferSizeSpinBox->setMaximum(99999);

        hboxLayout34->addWidget(vbvBufferSizeSpinBox);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        hboxLayout34->addWidget(label_12);

        spacer_55 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout34->addItem(spacer_55);


        gridLayout11->addLayout(hboxLayout34, 1, 1, 1, 1);

        hboxLayout35 = new QHBoxLayout();
        hboxLayout35->setObjectName(QString::fromUtf8("hboxLayout35"));
        vbvBufferOccupancySpinBox = new QSpinBox(groupBox);
        vbvBufferOccupancySpinBox->setObjectName(QString::fromUtf8("vbvBufferOccupancySpinBox"));
        vbvBufferOccupancySpinBox->setMaximum(100);
        vbvBufferOccupancySpinBox->setValue(90);

        hboxLayout35->addWidget(vbvBufferOccupancySpinBox);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        hboxLayout35->addWidget(label_13);

        spacer_58 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout35->addItem(spacer_58);


        gridLayout11->addLayout(hboxLayout35, 2, 1, 1, 1);

        hboxLayout36 = new QHBoxLayout();
        hboxLayout36->setObjectName(QString::fromUtf8("hboxLayout36"));
        vbvMaxBitrateSpinBox = new QSpinBox(groupBox);
        vbvMaxBitrateSpinBox->setObjectName(QString::fromUtf8("vbvMaxBitrateSpinBox"));
        vbvMaxBitrateSpinBox->setMaximum(99999);

        hboxLayout36->addWidget(vbvMaxBitrateSpinBox);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        hboxLayout36->addWidget(label_10);

        spacer_56 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout36->addItem(spacer_56);


        gridLayout11->addLayout(hboxLayout36, 0, 1, 1, 1);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        gridLayout11->addWidget(label_11, 1, 0, 1, 1);


        vboxLayout12->addLayout(gridLayout11);


        vboxLayout11->addWidget(groupBox);

        slicingGroupBox = new QGroupBox(tabAdvanced1);
        slicingGroupBox->setObjectName(QString::fromUtf8("slicingGroupBox"));
        gridLayout12 = new QGridLayout(slicingGroupBox);
        gridLayout12->setObjectName(QString::fromUtf8("gridLayout12"));
        label_25 = new QLabel(slicingGroupBox);
        label_25->setObjectName(QString::fromUtf8("label_25"));

        gridLayout12->addWidget(label_25, 2, 0, 1, 1);

        label_23 = new QLabel(slicingGroupBox);
        label_23->setObjectName(QString::fromUtf8("label_23"));

        gridLayout12->addWidget(label_23, 0, 0, 1, 1);

        hboxLayout37 = new QHBoxLayout();
        hboxLayout37->setObjectName(QString::fromUtf8("hboxLayout37"));
        maxSliceSizeSpinBox = new QSpinBox(slicingGroupBox);
        maxSliceSizeSpinBox->setObjectName(QString::fromUtf8("maxSliceSizeSpinBox"));
        maxSliceSizeSpinBox->setMaximum(2147483647);

        hboxLayout37->addWidget(maxSliceSizeSpinBox);

        label_32 = new QLabel(slicingGroupBox);
        label_32->setObjectName(QString::fromUtf8("label_32"));

        hboxLayout37->addWidget(label_32);

        spacer_54 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout37->addItem(spacer_54);


        gridLayout12->addLayout(hboxLayout37, 0, 1, 1, 2);

        label_24 = new QLabel(slicingGroupBox);
        label_24->setObjectName(QString::fromUtf8("label_24"));

        gridLayout12->addWidget(label_24, 1, 0, 1, 1);

        hboxLayout38 = new QHBoxLayout();
        hboxLayout38->setObjectName(QString::fromUtf8("hboxLayout38"));
        maxSliceMbSpinBox = new QSpinBox(slicingGroupBox);
        maxSliceMbSpinBox->setObjectName(QString::fromUtf8("maxSliceMbSpinBox"));
        maxSliceMbSpinBox->setMaximum(2147483647);

        hboxLayout38->addWidget(maxSliceMbSpinBox);

        spacer_57 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout38->addItem(spacer_57);


        gridLayout12->addLayout(hboxLayout38, 1, 1, 1, 1);

        hboxLayout39 = new QHBoxLayout();
        hboxLayout39->setObjectName(QString::fromUtf8("hboxLayout39"));
        slicesPerFrameSpinBox = new QSpinBox(slicingGroupBox);
        slicesPerFrameSpinBox->setObjectName(QString::fromUtf8("slicesPerFrameSpinBox"));
        slicesPerFrameSpinBox->setMaximum(2147483647);

        hboxLayout39->addWidget(slicesPerFrameSpinBox);

        spacer_53 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout39->addItem(spacer_53);


        gridLayout12->addLayout(hboxLayout39, 2, 1, 1, 1);


        vboxLayout11->addWidget(slicingGroupBox);

        groupBox_21 = new QGroupBox(tabAdvanced1);
        groupBox_21->setObjectName(QString::fromUtf8("groupBox_21"));
        vboxLayout13 = new QVBoxLayout(groupBox_21);
        vboxLayout13->setObjectName(QString::fromUtf8("vboxLayout13"));
        _12 = new QHBoxLayout();
        _12->setObjectName(QString::fromUtf8("_12"));
        zoneTableView = new QTableView(groupBox_21);
        zoneTableView->setObjectName(QString::fromUtf8("zoneTableView"));
        zoneTableView->setSelectionMode(QAbstractItemView::SingleSelection);
        zoneTableView->setSelectionBehavior(QAbstractItemView::SelectRows);

        _12->addWidget(zoneTableView);

        _13 = new QVBoxLayout();
        _13->setObjectName(QString::fromUtf8("_13"));
        zoneAddButton = new QPushButton(groupBox_21);
        zoneAddButton->setObjectName(QString::fromUtf8("zoneAddButton"));

        _13->addWidget(zoneAddButton);

        zoneEditButton = new QPushButton(groupBox_21);
        zoneEditButton->setObjectName(QString::fromUtf8("zoneEditButton"));

        _13->addWidget(zoneEditButton);

        zoneDeleteButton = new QPushButton(groupBox_21);
        zoneDeleteButton->setObjectName(QString::fromUtf8("zoneDeleteButton"));

        _13->addWidget(zoneDeleteButton);

        spacer_59 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        _13->addItem(spacer_59);


        _12->addLayout(_13);


        vboxLayout13->addLayout(_12);


        vboxLayout11->addWidget(groupBox_21);

        tabWidget->addTab(tabAdvanced1, QString());
        tabAdvanced2 = new QWidget();
        tabAdvanced2->setObjectName(QString::fromUtf8("tabAdvanced2"));
        verticalLayout_4 = new QVBoxLayout(tabAdvanced2);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        groupBox_17 = new QGroupBox(tabAdvanced2);
        groupBox_17->setObjectName(QString::fromUtf8("groupBox_17"));
        _2 = new QVBoxLayout(groupBox_17);
        _2->setObjectName(QString::fromUtf8("_2"));
        _4 = new QVBoxLayout();
        _4->setObjectName(QString::fromUtf8("_4"));
        threadDisableRadioButton = new QRadioButton(groupBox_17);
        threadDisableRadioButton->setObjectName(QString::fromUtf8("threadDisableRadioButton"));

        _4->addWidget(threadDisableRadioButton);

        threadAutoDetectRadioButton = new QRadioButton(groupBox_17);
        threadAutoDetectRadioButton->setObjectName(QString::fromUtf8("threadAutoDetectRadioButton"));
        threadAutoDetectRadioButton->setChecked(true);

        _4->addWidget(threadAutoDetectRadioButton);

        _14 = new QHBoxLayout();
        _14->setObjectName(QString::fromUtf8("_14"));
        threadCustomRadioButton = new QRadioButton(groupBox_17);
        threadCustomRadioButton->setObjectName(QString::fromUtf8("threadCustomRadioButton"));

        _14->addWidget(threadCustomRadioButton);

        threadCustomSpinBox = new QSpinBox(groupBox_17);
        threadCustomSpinBox->setObjectName(QString::fromUtf8("threadCustomSpinBox"));
        threadCustomSpinBox->setEnabled(false);
        threadCustomSpinBox->setMinimum(2);
        threadCustomSpinBox->setMaximum(32);

        _14->addWidget(threadCustomSpinBox);

        spacer_2 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _14->addItem(spacer_2);


        _4->addLayout(_14);


        _2->addLayout(_4);

        repeatabilityCheckBox = new QCheckBox(groupBox_17);
        repeatabilityCheckBox->setObjectName(QString::fromUtf8("repeatabilityCheckBox"));

        _2->addWidget(repeatabilityCheckBox);

        sliceThreadingCheckBox = new QCheckBox(groupBox_17);
        sliceThreadingCheckBox->setObjectName(QString::fromUtf8("sliceThreadingCheckBox"));

        _2->addWidget(sliceThreadingCheckBox);

        _15 = new QHBoxLayout();
        _15->setObjectName(QString::fromUtf8("_15"));
        threadedLookaheadCheckBox = new QCheckBox(groupBox_17);
        threadedLookaheadCheckBox->setObjectName(QString::fromUtf8("threadedLookaheadCheckBox"));

        _15->addWidget(threadedLookaheadCheckBox);

        threadedLookaheadSpinBox = new QSpinBox(groupBox_17);
        threadedLookaheadSpinBox->setObjectName(QString::fromUtf8("threadedLookaheadSpinBox"));
        threadedLookaheadSpinBox->setEnabled(false);
        threadedLookaheadSpinBox->setMaximum(250);

        _15->addWidget(threadedLookaheadSpinBox);

        lblThreadedFrames = new QLabel(groupBox_17);
        lblThreadedFrames->setObjectName(QString::fromUtf8("lblThreadedFrames"));
        lblThreadedFrames->setEnabled(false);

        _15->addWidget(lblThreadedFrames);

        spacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _15->addItem(spacer);


        _2->addLayout(_15);


        verticalLayout_4->addWidget(groupBox_17);

        verticalSpacer = new QSpacerItem(20, 256, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        tabWidget->addTab(tabAdvanced2, QString());
        tabOutput = new QWidget();
        tabOutput->setObjectName(QString::fromUtf8("tabOutput"));
        vboxLayout14 = new QVBoxLayout(tabOutput);
        vboxLayout14->setObjectName(QString::fromUtf8("vboxLayout14"));
        groupBox_16 = new QGroupBox(tabOutput);
        groupBox_16->setObjectName(QString::fromUtf8("groupBox_16"));
        vboxLayout15 = new QVBoxLayout(groupBox_16);
        vboxLayout15->setObjectName(QString::fromUtf8("vboxLayout15"));
        accessUnitCheckBox = new QCheckBox(groupBox_16);
        accessUnitCheckBox->setObjectName(QString::fromUtf8("accessUnitCheckBox"));

        vboxLayout15->addWidget(accessUnitCheckBox);


        vboxLayout14->addWidget(groupBox_16);

        groupBox_5 = new QGroupBox(tabOutput);
        groupBox_5->setObjectName(QString::fromUtf8("groupBox_5"));
        verticalLayout_2 = new QVBoxLayout(groupBox_5);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label_52 = new QLabel(groupBox_5);
        label_52->setObjectName(QString::fromUtf8("label_52"));
        label_52->setWordWrap(true);

        verticalLayout_2->addWidget(label_52);

        spacerItem12 = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_2->addItem(spacerItem12);

        gridLayout13 = new QGridLayout();
        gridLayout13->setObjectName(QString::fromUtf8("gridLayout13"));
        label_51 = new QLabel(groupBox_5);
        label_51->setObjectName(QString::fromUtf8("label_51"));

        gridLayout13->addWidget(label_51, 0, 0, 1, 1);

        _6 = new QHBoxLayout();
        _6->setObjectName(QString::fromUtf8("_6"));
        overscanComboBox = new QComboBox(groupBox_5);
        overscanComboBox->addItem(QString());
        overscanComboBox->addItem(QString());
        overscanComboBox->addItem(QString());
        overscanComboBox->setObjectName(QString::fromUtf8("overscanComboBox"));

        _6->addWidget(overscanComboBox);

        spacer_70 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _6->addItem(spacer_70);


        gridLayout13->addLayout(_6, 0, 1, 1, 1);

        hrdLabel = new QLabel(groupBox_5);
        hrdLabel->setObjectName(QString::fromUtf8("hrdLabel"));

        gridLayout13->addWidget(hrdLabel, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        hrdComboBox = new QComboBox(groupBox_5);
        hrdComboBox->addItem(QString());
        hrdComboBox->addItem(QString());
        hrdComboBox->addItem(QString());
        hrdComboBox->setObjectName(QString::fromUtf8("hrdComboBox"));

        horizontalLayout_3->addWidget(hrdComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        gridLayout13->addLayout(horizontalLayout_3, 1, 1, 1, 1);

        label_49 = new QLabel(groupBox_5);
        label_49->setObjectName(QString::fromUtf8("label_49"));

        gridLayout13->addWidget(label_49, 2, 0, 1, 1);

        _10 = new QHBoxLayout();
        _10->setObjectName(QString::fromUtf8("_10"));
        chromaSampleSpinBox = new QSpinBox(groupBox_5);
        chromaSampleSpinBox->setObjectName(QString::fromUtf8("chromaSampleSpinBox"));
        chromaSampleSpinBox->setMaximum(4);

        _10->addWidget(chromaSampleSpinBox);

        spacer_66 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _10->addItem(spacer_66);


        gridLayout13->addLayout(_10, 2, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout13);

        fullRangeSamplesCheckBox = new QCheckBox(groupBox_5);
        fullRangeSamplesCheckBox->setObjectName(QString::fromUtf8("fullRangeSamplesCheckBox"));

        verticalLayout_2->addWidget(fullRangeSamplesCheckBox);


        vboxLayout14->addWidget(groupBox_5);

        spacer_60 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout14->addItem(spacer_60);

        tabWidget->addTab(tabOutput, QString());

        _11->addWidget(tabWidget);

        hboxLayout40 = new QHBoxLayout();
        hboxLayout40->setObjectName(QString::fromUtf8("hboxLayout40"));
        buttonBox = new QDialogButtonBox(x265ConfigDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout40->addWidget(buttonBox);


        _11->addLayout(hboxLayout40);

        QWidget::setTabOrder(configurationComboBox, saveAsButton);
        QWidget::setTabOrder(saveAsButton, deleteButton);
        QWidget::setTabOrder(deleteButton, tabWidget);
        QWidget::setTabOrder(tabWidget, encodingModeComboBox);
        QWidget::setTabOrder(encodingModeComboBox, targetRateControlSpinBox);
        QWidget::setTabOrder(targetRateControlSpinBox, quantiserSlider);
        QWidget::setTabOrder(quantiserSlider, quantiserSpinBox);
        QWidget::setTabOrder(quantiserSpinBox, meMethodComboBox);
        QWidget::setTabOrder(meMethodComboBox, meSlider);
        QWidget::setTabOrder(meSlider, meSpinBox);
        QWidget::setTabOrder(meSpinBox, mvRangeSpinBox);
        QWidget::setTabOrder(mvRangeSpinBox, weightedPPredictComboBox);
        QWidget::setTabOrder(weightedPPredictComboBox, weightedPredictCheckBox);
        QWidget::setTabOrder(weightedPredictCheckBox, bIntraCheckBox);
        QWidget::setTabOrder(bIntraCheckBox, constrainedIntraCheckBox);
        QWidget::setTabOrder(constrainedIntraCheckBox, rectInterCheckBox);
        QWidget::setTabOrder(rectInterCheckBox, AMPInterCheckBox);
        QWidget::setTabOrder(AMPInterCheckBox, limitInterModesCheckBox);
        QWidget::setTabOrder(limitInterModesCheckBox, loopFilterCheckBox);
        QWidget::setTabOrder(loopFilterCheckBox, openGopCheckBox);
        QWidget::setTabOrder(openGopCheckBox, interlacedCheckBox);
        QWidget::setTabOrder(interlacedCheckBox, interlacedComboBox);
        QWidget::setTabOrder(interlacedComboBox, refFramesSpinBox);
        QWidget::setTabOrder(refFramesSpinBox, limitRefCUCheckBox);
        QWidget::setTabOrder(limitRefCUCheckBox, limitRefDepthCheckBox);
        QWidget::setTabOrder(limitRefDepthCheckBox, maxBFramesSpinBox);
        QWidget::setTabOrder(maxBFramesSpinBox, BFrameBiasSpinBox);
        QWidget::setTabOrder(BFrameBiasSpinBox, adaptiveBFrameComboBox);
        QWidget::setTabOrder(adaptiveBFrameComboBox, bFrameRefComboBox);
        QWidget::setTabOrder(bFrameRefComboBox, minGopSizeSpinBox);
        QWidget::setTabOrder(minGopSizeSpinBox, maxGopSizeSpinBox);
        QWidget::setTabOrder(maxGopSizeSpinBox, IFrameThresholdSpinBox);
        QWidget::setTabOrder(IFrameThresholdSpinBox, fastPSkipCheckBox);
        QWidget::setTabOrder(fastPSkipCheckBox, dctDecimateCheckBox);
        QWidget::setTabOrder(dctDecimateCheckBox, rdoSpinBox);
        QWidget::setTabOrder(rdoSpinBox, psychoRdoSpinBox);
        QWidget::setTabOrder(psychoRdoSpinBox, matrixFlatRadioButton);
        QWidget::setTabOrder(matrixFlatRadioButton, matrixJvtRadioButton);
        QWidget::setTabOrder(matrixJvtRadioButton, matrixCustomRadioButton);
        QWidget::setTabOrder(matrixCustomRadioButton, matrixCustomEditButton);
        QWidget::setTabOrder(matrixCustomEditButton, quantiserMaxStepSpinBox);
        QWidget::setTabOrder(quantiserMaxStepSpinBox, quantiserIpRatioSpinBox);
        QWidget::setTabOrder(quantiserIpRatioSpinBox, quantiserPbRatioSpinBox);
        QWidget::setTabOrder(quantiserPbRatioSpinBox, cbChromaLumaOffsetSpinBox);
        QWidget::setTabOrder(cbChromaLumaOffsetSpinBox, quantiserCurveCompressSpinBox);
        QWidget::setTabOrder(quantiserCurveCompressSpinBox, quantiserBeforeCompressSpinBox);
        QWidget::setTabOrder(quantiserBeforeCompressSpinBox, quantiserAfterCompressSpinBox);
        QWidget::setTabOrder(quantiserAfterCompressSpinBox, aqVarianceCheckBox);
        QWidget::setTabOrder(aqVarianceCheckBox, aqAlgoComboBox);
        QWidget::setTabOrder(aqAlgoComboBox, aqStrengthSpinBox);
        QWidget::setTabOrder(aqStrengthSpinBox, vbvMaxBitrateSpinBox);
        QWidget::setTabOrder(vbvMaxBitrateSpinBox, vbvBufferSizeSpinBox);
        QWidget::setTabOrder(vbvBufferSizeSpinBox, vbvBufferOccupancySpinBox);
        QWidget::setTabOrder(vbvBufferOccupancySpinBox, maxSliceSizeSpinBox);
        QWidget::setTabOrder(maxSliceSizeSpinBox, maxSliceMbSpinBox);
        QWidget::setTabOrder(maxSliceMbSpinBox, slicesPerFrameSpinBox);
        QWidget::setTabOrder(slicesPerFrameSpinBox, zoneTableView);
        QWidget::setTabOrder(zoneTableView, zoneAddButton);
        QWidget::setTabOrder(zoneAddButton, zoneEditButton);
        QWidget::setTabOrder(zoneEditButton, zoneDeleteButton);
        QWidget::setTabOrder(zoneDeleteButton, threadDisableRadioButton);
        QWidget::setTabOrder(threadDisableRadioButton, threadAutoDetectRadioButton);
        QWidget::setTabOrder(threadAutoDetectRadioButton, threadCustomRadioButton);
        QWidget::setTabOrder(threadCustomRadioButton, threadCustomSpinBox);
        QWidget::setTabOrder(threadCustomSpinBox, repeatabilityCheckBox);
        QWidget::setTabOrder(repeatabilityCheckBox, sliceThreadingCheckBox);
        QWidget::setTabOrder(sliceThreadingCheckBox, threadedLookaheadCheckBox);
        QWidget::setTabOrder(threadedLookaheadCheckBox, threadedLookaheadSpinBox);
        QWidget::setTabOrder(threadedLookaheadSpinBox, sarCustomRadioButton);
        QWidget::setTabOrder(sarCustomRadioButton, sarCustomSpinBox1);
        QWidget::setTabOrder(sarCustomSpinBox1, sarCustomSpinBox2);
        QWidget::setTabOrder(sarCustomSpinBox2, sarPredefinedRadioButton);
        QWidget::setTabOrder(sarPredefinedRadioButton, sarPredefinedComboBox);
        QWidget::setTabOrder(sarPredefinedComboBox, sarAsInputRadioButton);
        QWidget::setTabOrder(sarAsInputRadioButton, videoFormatComboBox);
        QWidget::setTabOrder(videoFormatComboBox, colourPrimariesComboBox);
        QWidget::setTabOrder(colourPrimariesComboBox, transferCharacteristicsComboBox);
        QWidget::setTabOrder(transferCharacteristicsComboBox, colourMatrixComboBox);
        QWidget::setTabOrder(colourMatrixComboBox, accessUnitCheckBox);
        QWidget::setTabOrder(accessUnitCheckBox, overscanComboBox);
        QWidget::setTabOrder(overscanComboBox, hrdComboBox);
        QWidget::setTabOrder(hrdComboBox, chromaSampleSpinBox);
        QWidget::setTabOrder(chromaSampleSpinBox, fullRangeSamplesCheckBox);
        QWidget::setTabOrder(fullRangeSamplesCheckBox, buttonBox);

        retranslateUi(x265ConfigDialog);
        QObject::connect(sarPredefinedRadioButton, SIGNAL(toggled(bool)), sarPredefinedComboBox, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomSpinBox1, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomSpinBox2, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomLabel, SLOT(setEnabled(bool)));
        QObject::connect(matrixCustomRadioButton, SIGNAL(toggled(bool)), matrixCustomEditButton, SLOT(setEnabled(bool)));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqStrengthLabel, SLOT(setEnabled(bool)));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqStrengthSpinBox, SLOT(setEnabled(bool)));
        QObject::connect(buttonBox, SIGNAL(accepted()), x265ConfigDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), x265ConfigDialog, SLOT(reject()));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqAlgoComboBox, SLOT(setEnabled(bool)));
        QObject::connect(interlacedCheckBox, SIGNAL(toggled(bool)), interlacedComboBox, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(0);
        presetComboBox->setCurrentIndex(-1);
        encodingModeComboBox->setCurrentIndex(3);
        meMethodComboBox->setCurrentIndex(0);
        videoFormatComboBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(x265ConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *x265ConfigDialog)
    {
        x265ConfigDialog->setWindowTitle(QCoreApplication::translate("x265ConfigDialog", "x265 Configuration", nullptr));
        label_3->setText(QCoreApplication::translate("x265ConfigDialog", "Configuration:", nullptr));
        saveAsButton->setText(QCoreApplication::translate("x265ConfigDialog", "Save As", nullptr));
        deleteButton->setText(QCoreApplication::translate("x265ConfigDialog", "Delete", nullptr));
        groupBoxBasic->setTitle(QCoreApplication::translate("x265ConfigDialog", "Basic", nullptr));
        useAdvancedConfigurationCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Use advanced configuration", nullptr));
        label_46->setText(QCoreApplication::translate("x265ConfigDialog", "Profile:", nullptr));
        label_45->setText(QCoreApplication::translate("x265ConfigDialog", "Tuning:", nullptr));
        labelPoolThread->setText(QCoreApplication::translate("x265ConfigDialog", "Pool Threads ", nullptr));
        label_41->setText(QCoreApplication::translate("x265ConfigDialog", "Preset:", nullptr));
        labelFrameThreads->setText(QCoreApplication::translate("x265ConfigDialog", "Frame Threads ", nullptr));
        label_53->setText(QCoreApplication::translate("x265ConfigDialog", "IDC Level:", nullptr));
        labelBitDepth->setText(QCoreApplication::translate("x265ConfigDialog", "Output Bit Depth:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("x265ConfigDialog", "Rate Control", nullptr));
        targetRateControlLabel1->setText(QCoreApplication::translate("x265ConfigDialog", "Target Video Size:", nullptr));
        encodingModeComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Constant Bitrate (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Constant Quantiser (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Constant Rate Factor (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(3, QCoreApplication::translate("x265ConfigDialog", "Video Size (Two Pass)", nullptr));
        encodingModeComboBox->setItemText(4, QCoreApplication::translate("x265ConfigDialog", "Average Bitrate (Two Pass)", nullptr));

        label->setText(QCoreApplication::translate("x265ConfigDialog", "Encoding Mode:", nullptr));
        targetRateControlSpinBox->setPrefix(QString());
        targetRateControlLabel2->setText(QCoreApplication::translate("x265ConfigDialog", "MB", nullptr));
        quantiserLabel1->setText(QCoreApplication::translate("x265ConfigDialog", "0 (High Quality)", nullptr));
        quantiserLabel2->setText(QCoreApplication::translate("x265ConfigDialog", "Quantiser", nullptr));
        quantiserLabel3->setText(QCoreApplication::translate("x265ConfigDialog", "51 (Low Quality)", nullptr));
        strictCbrCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Use Strict Constant Bitrate Mode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), QCoreApplication::translate("x265ConfigDialog", "General", nullptr));
        groupBox_20->setTitle(QCoreApplication::translate("x265ConfigDialog", "Advanced Rate Control", nullptr));
        maxCrfCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Constant Rate Factor", nullptr));
        quantiserLabel1_2->setText(QCoreApplication::translate("x265ConfigDialog", "0 (High Quality)", nullptr));
        quantiserLabel2_2->setText(QCoreApplication::translate("x265ConfigDialog", "Quantiser", nullptr));
        quantiserLabel3_2->setText(QCoreApplication::translate("x265ConfigDialog", "51 (Low Quality)", nullptr));
        cuTreeCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Coding Unit-tree Rate Control", nullptr));
        lblLookahead->setText(QCoreApplication::translate("x265ConfigDialog", "Frametype Lookahead:", nullptr));
        lblLookaheadFrames->setText(QCoreApplication::translate("x265ConfigDialog", "frames", nullptr));
        label_55->setText(QCoreApplication::translate("x265ConfigDialog", "Sequence Parameter Set Identifer:", nullptr));
        spsiComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "0", nullptr));
        spsiComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "1", nullptr));
        spsiComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "3", nullptr));
        spsiComboBox->setItemText(3, QCoreApplication::translate("x265ConfigDialog", "7", nullptr));
        spsiComboBox->setItemText(4, QCoreApplication::translate("x265ConfigDialog", "15", nullptr));
        spsiComboBox->setItemText(5, QCoreApplication::translate("x265ConfigDialog", "31", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tabAdvancedRC), QCoreApplication::translate("x265ConfigDialog", "Advanced RC", nullptr));
        groupBox_11->setTitle(QCoreApplication::translate("x265ConfigDialog", "Motion Estimation", nullptr));
        label_38->setText(QCoreApplication::translate("x265ConfigDialog", "Motion Estimation Method:", nullptr));
        meMethodComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Diamond Search", nullptr));
        meMethodComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Hexagonal Search", nullptr));
        meMethodComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Uneven Multi-hexagonal Search", nullptr));
        meMethodComboBox->setItemText(3, QCoreApplication::translate("x265ConfigDialog", "Star Search", nullptr));
        meMethodComboBox->setItemText(4, QCoreApplication::translate("x265ConfigDialog", "Exhaustive Search", nullptr));

        label_35->setText(QCoreApplication::translate("x265ConfigDialog", "1 (Fast)", nullptr));
        label_36->setText(QCoreApplication::translate("x265ConfigDialog", "Subpixel Refinement", nullptr));
        label_37->setText(QCoreApplication::translate("x265ConfigDialog", "7 (Best)", nullptr));
        groupBox_19->setTitle(QCoreApplication::translate("x265ConfigDialog", "Motion Vector", nullptr));
        label_39->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Motion Vector Search Range:", nullptr));
        groupBox_18->setTitle(QCoreApplication::translate("x265ConfigDialog", "Prediction", nullptr));
        lblBPredict->setText(QCoreApplication::translate("x265ConfigDialog", "Prediction for B-frames:", nullptr));
        weightedPredictCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Weighted Prediction", nullptr));
        bIntraCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Intra Prediction", nullptr));
        constrainedIntraCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Constrained Intra Prediction", nullptr));
        lblMParts->setText(QCoreApplication::translate("x265ConfigDialog", "Motion Partitions:", nullptr));
        rectInterCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Rectangular", nullptr));
        AMPInterCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Asymmetric", nullptr));
        limitInterModesCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Limit Motion Partition Modes", nullptr));
        lblWeightedPPredict->setText(QCoreApplication::translate("x265ConfigDialog", "Weighted Prediction for P-frames:", nullptr));
        weightedPPredictComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Disabled", nullptr));
        weightedPPredictComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Weighted References", nullptr));
        weightedPPredictComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Weighted References + Duplicates", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tabMotion), QCoreApplication::translate("x265ConfigDialog", "Motion", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("x265ConfigDialog", "Frame Encoding", nullptr));
        loopFilterCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Loop Filter", nullptr));
        openGopCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Open GOP", nullptr));
        interlacedCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Interlaced:", nullptr));
        interlacedComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Top Field First", nullptr));
        interlacedComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Bottom Field First", nullptr));

        maxRefFramesLabel->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Reference Frames:", nullptr));
        refLimitLabel->setText(QCoreApplication::translate("x265ConfigDialog", "Limit References by:", nullptr));
        limitRefCUCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "CU", nullptr));
        limitRefDepthCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Depth", nullptr));
        groupBoxBframes->setTitle(QCoreApplication::translate("x265ConfigDialog", "B-frames", nullptr));
        label_31->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Consecutive B-frames:", nullptr));
        label_29->setText(QCoreApplication::translate("x265ConfigDialog", "B-frame Bias:", nullptr));
        label_4->setText(QCoreApplication::translate("x265ConfigDialog", "Adaptive B-frame Decision:", nullptr));
        adaptiveBFrameComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Disabled", nullptr));
        adaptiveBFrameComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Fast", nullptr));
        adaptiveBFrameComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Optimal", nullptr));

        label_33->setText(QCoreApplication::translate("x265ConfigDialog", "B-frames as References:", nullptr));
        bFrameRefComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Disabled", nullptr));
        bFrameRefComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Enabled", nullptr));

        groupBox_8->setTitle(QCoreApplication::translate("x265ConfigDialog", "I-frames", nullptr));
        label_34->setText(QCoreApplication::translate("x265ConfigDialog", "GOP Size:", nullptr));
        label_28->setText(QCoreApplication::translate("x265ConfigDialog", "Minimum:", nullptr));
        label_26->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum:", nullptr));
        label_27->setText(QCoreApplication::translate("x265ConfigDialog", "I-frame Threshold:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabFrame), QCoreApplication::translate("x265ConfigDialog", "Frame", nullptr));
        groupBox_12->setTitle(QCoreApplication::translate("x265ConfigDialog", "Analysis", nullptr));
        fastPSkipCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Fast Skip Detection on P-frames", nullptr));
        dctDecimateCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "DCT Decimation on P-frames", nullptr));
        lblRDO->setText(QCoreApplication::translate("x265ConfigDialog", "Rate Distortion Optimisation:", nullptr));
        lblPsychoRDO->setText(QCoreApplication::translate("x265ConfigDialog", "Level:", nullptr));
        lblRDOPsyVS->setText(QCoreApplication::translate("x265ConfigDialog", "Psycho-visual Strength:", nullptr));
        lblRDOQ->setText(QCoreApplication::translate("x265ConfigDialog", "RDO in Quantization:", nullptr));
        lblRDOQLevel->setText(QCoreApplication::translate("x265ConfigDialog", "Level:", nullptr));
        lblPsyRDOQ->setText(QCoreApplication::translate("x265ConfigDialog", "Psycho-visual Strength:", nullptr));
        label_15->setText(QCoreApplication::translate("x265ConfigDialog", "Noise Reduction Intra:", nullptr));
        label_16->setText(QCoreApplication::translate("x265ConfigDialog", "Noise Reduction Inter:", nullptr));
        strongIntraSmoothingCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Strong Intra Smoothing", nullptr));
        groupBoxQuantMatrix->setTitle(QCoreApplication::translate("x265ConfigDialog", "Quantisation Matrix", nullptr));
        matrixFlatRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Flat Matrix", nullptr));
        matrixJvtRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "JVT Matrix", nullptr));
        matrixCustomRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Custom Matrix", nullptr));
        matrixCustomEditButton->setText(QCoreApplication::translate("x265ConfigDialog", "Edit", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAnalysis), QCoreApplication::translate("x265ConfigDialog", "Analysis", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("x265ConfigDialog", "Quantiser Control", nullptr));
        label_20->setText(QCoreApplication::translate("x265ConfigDialog", "Chroma to Luma Quantiser Offset:", nullptr));
        label_6->setText(QCoreApplication::translate("x265ConfigDialog", "I and P-frame Quantiser Ratio:", nullptr));
        label_17->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Quantiser Step:", nullptr));
        label_40->setText(QCoreApplication::translate("x265ConfigDialog", "Cb", nullptr));
        label_54->setText(QCoreApplication::translate("x265ConfigDialog", "Cr", nullptr));
        label_7->setText(QCoreApplication::translate("x265ConfigDialog", "P and B-frame Quantiser Ratio:", nullptr));
        groupBoxQuantCurveCompress->setTitle(QCoreApplication::translate("x265ConfigDialog", "Quantiser Curve Compression", nullptr));
        label_8->setText(QCoreApplication::translate("x265ConfigDialog", "Quantiser Curve Compression:", nullptr));
        label_18->setText(QCoreApplication::translate("x265ConfigDialog", "%", nullptr));
        label_21->setText(QCoreApplication::translate("x265ConfigDialog", "Reduce Fluctuation Before Curve Compression:", nullptr));
        label_22->setText(QCoreApplication::translate("x265ConfigDialog", "Reduce Fluctuation After Curve Compression:", nullptr));
        aqGroupBox->setTitle(QCoreApplication::translate("x265ConfigDialog", "Adaptive Quantisation", nullptr));
        aqVarianceCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Variance AQ:", nullptr));
        aqAlgoComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Normal", nullptr));
        aqAlgoComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Auto Variance AQ", nullptr));
        aqAlgoComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Auto-Variance Biased", nullptr));
        aqAlgoComboBox->setItemText(3, QCoreApplication::translate("x265ConfigDialog", "Auto-Variance Edge", nullptr));

        aqStrengthLabel->setText(QCoreApplication::translate("x265ConfigDialog", "Strength:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabQuantiser), QCoreApplication::translate("x265ConfigDialog", "Quantiser", nullptr));
        groupColor->setTitle(QCoreApplication::translate("x265ConfigDialog", "Color Description", nullptr));
        label_50->setText(QCoreApplication::translate("x265ConfigDialog", "Video Format:", nullptr));
        videoFormatComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Undefined", nullptr));
        videoFormatComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Component", nullptr));
        videoFormatComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "PAL", nullptr));
        videoFormatComboBox->setItemText(3, QCoreApplication::translate("x265ConfigDialog", "NTSC", nullptr));
        videoFormatComboBox->setItemText(4, QCoreApplication::translate("x265ConfigDialog", "SECAM", nullptr));
        videoFormatComboBox->setItemText(5, QCoreApplication::translate("x265ConfigDialog", "MAC", nullptr));

        label_19->setText(QCoreApplication::translate("x265ConfigDialog", "Colour Primaries:", nullptr));
        label_48->setText(QCoreApplication::translate("x265ConfigDialog", "Transfer Characteristics:", nullptr));
        label_47->setText(QCoreApplication::translate("x265ConfigDialog", "Colour Matrix:", nullptr));
        groupBoxPAR->setTitle(QCoreApplication::translate("x265ConfigDialog", "Pixel Aspect Ratio", nullptr));
        labelPAR->setText(QCoreApplication::translate("x265ConfigDialog", "The value set here will almost always be ignored in favor of the aspect ratio stored in the container.  Configure that via the options in Output Format for the muxer chosen.", nullptr));
        sarUnspecifiedRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Unspecified", "PAR"));
        sarPredefinedRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Predefined Aspect Ratio:", nullptr));
        sarCustomRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Custom Aspect Ratio:", "PAR"));
        sarCustomLabel->setText(QCoreApplication::translate("x265ConfigDialog", ":", nullptr));
        sarAsInputRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Same as Input", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabDispaly), QCoreApplication::translate("x265ConfigDialog", "Display", nullptr));
        groupBox->setTitle(QCoreApplication::translate("x265ConfigDialog", "Video Buffer Verifier", nullptr));
        label_9->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum VBV Bitrate:", nullptr));
        label_14->setText(QCoreApplication::translate("x265ConfigDialog", "Initial VBV Buffer Occupancy:", nullptr));
        label_12->setText(QCoreApplication::translate("x265ConfigDialog", "kbit", nullptr));
        label_13->setText(QCoreApplication::translate("x265ConfigDialog", "%", nullptr));
        label_10->setText(QCoreApplication::translate("x265ConfigDialog", "kbit/s", nullptr));
        label_11->setText(QCoreApplication::translate("x265ConfigDialog", "VBV Buffer Size:", nullptr));
        slicingGroupBox->setTitle(QCoreApplication::translate("x265ConfigDialog", "Slicing", nullptr));
        label_25->setText(QCoreApplication::translate("x265ConfigDialog", "Slices per Frame:", nullptr));
        label_23->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Size per Slice:", nullptr));
        label_32->setText(QCoreApplication::translate("x265ConfigDialog", "bytes", nullptr));
        label_24->setText(QCoreApplication::translate("x265ConfigDialog", "Maximum Macroblocks per Slice:", nullptr));
        groupBox_21->setTitle(QCoreApplication::translate("x265ConfigDialog", "Zones", nullptr));
        zoneAddButton->setText(QCoreApplication::translate("x265ConfigDialog", "Add", nullptr));
        zoneEditButton->setText(QCoreApplication::translate("x265ConfigDialog", "Edit", nullptr));
        zoneDeleteButton->setText(QCoreApplication::translate("x265ConfigDialog", "Delete", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced1), QCoreApplication::translate("x265ConfigDialog", "Advanced 1", nullptr));
        groupBox_17->setTitle(QCoreApplication::translate("x265ConfigDialog", "Multithreading", nullptr));
        threadDisableRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Disable", nullptr));
        threadAutoDetectRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Auto-detect", nullptr));
        threadCustomRadioButton->setText(QCoreApplication::translate("x265ConfigDialog", "Custom:", "multithreading"));
        repeatabilityCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Enforce Repeatability", nullptr));
        sliceThreadingCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Slice-based Threading", nullptr));
        threadedLookaheadCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Custom Threaded Lookahead Buffer:", nullptr));
        lblThreadedFrames->setText(QCoreApplication::translate("x265ConfigDialog", "frames", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced2), QCoreApplication::translate("x265ConfigDialog", "Advanced 2", nullptr));
        groupBox_16->setTitle(QCoreApplication::translate("x265ConfigDialog", "Output", nullptr));
        accessUnitCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Generate Access Unit Delimiters", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("x265ConfigDialog", "Video Usability Information", nullptr));
        label_52->setText(QCoreApplication::translate("x265ConfigDialog", "These settings are only suggestions for the playback equipment.  Use at your own risk.", nullptr));
        label_51->setText(QCoreApplication::translate("x265ConfigDialog", "Overscan:", nullptr));
        overscanComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "Undefined", nullptr));
        overscanComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "Show", nullptr));
        overscanComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "Crop", nullptr));

        hrdLabel->setText(QCoreApplication::translate("x265ConfigDialog", "HRD Parameters:", nullptr));
        hrdComboBox->setItemText(0, QCoreApplication::translate("x265ConfigDialog", "None", nullptr));
        hrdComboBox->setItemText(1, QCoreApplication::translate("x265ConfigDialog", "VBR", nullptr));
        hrdComboBox->setItemText(2, QCoreApplication::translate("x265ConfigDialog", "CBR", nullptr));

        label_49->setText(QCoreApplication::translate("x265ConfigDialog", "Chroma Sample Location:", nullptr));
        fullRangeSamplesCheckBox->setText(QCoreApplication::translate("x265ConfigDialog", "Full Range Samples", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabOutput), QCoreApplication::translate("x265ConfigDialog", "Output", nullptr));
    } // retranslateUi

};

namespace Ui {
    class x265ConfigDialog: public Ui_x265ConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_X265CONFIGDIALOG_H
